Class: Aws::ElasticBeanstalk::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ElasticBeanstalk::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-elasticbeanstalk/client.rb,
sig/client.rbs
Overview
An API client for ElasticBeanstalk. To construct a client, you need to configure a :region and :credentials.
client = Aws::ElasticBeanstalk::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _ApplyEnvironmentManagedActionResponseSuccess, _CheckDNSAvailabilityResponseSuccess, _ComposeEnvironmentsResponseSuccess, _CreateApplicationResponseSuccess, _CreateApplicationVersionResponseSuccess, _CreateConfigurationTemplateResponseSuccess, _CreateEnvironmentResponseSuccess, _CreatePlatformVersionResponseSuccess, _CreateStorageLocationResponseSuccess, _DeletePlatformVersionResponseSuccess, _DescribeAccountAttributesResponseSuccess, _DescribeApplicationVersionsResponseSuccess, _DescribeApplicationsResponseSuccess, _DescribeConfigurationOptionsResponseSuccess, _DescribeConfigurationSettingsResponseSuccess, _DescribeEnvironmentHealthResponseSuccess, _DescribeEnvironmentManagedActionHistoryResponseSuccess, _DescribeEnvironmentManagedActionsResponseSuccess, _DescribeEnvironmentResourcesResponseSuccess, _DescribeEnvironmentsResponseSuccess, _DescribeEventsResponseSuccess, _DescribeInstancesHealthResponseSuccess, _DescribePlatformVersionResponseSuccess, _ListAvailableSolutionStacksResponseSuccess, _ListPlatformBranchesResponseSuccess, _ListPlatformVersionsResponseSuccess, _ListTagsForResourceResponseSuccess, _RetrieveEnvironmentInfoResponseSuccess, _TerminateEnvironmentResponseSuccess, _UpdateApplicationResourceLifecycleResponseSuccess, _UpdateApplicationResponseSuccess, _UpdateApplicationVersionResponseSuccess, _UpdateConfigurationTemplateResponseSuccess, _UpdateEnvironmentResponseSuccess, _ValidateConfigurationSettingsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#abort_environment_update(params = {}) ⇒ Struct
Cancels in-progress environment configuration update or application version deployment.
-
#apply_environment_managed_action(params = {}) ⇒ Types::ApplyEnvironmentManagedActionResult
Applies a scheduled managed action immediately.
-
#associate_environment_operations_role(params = {}) ⇒ Struct
The operations role feature of Elastic Beanstalk is in beta release and is subject to change.
-
#check_dns_availability(params = {}) ⇒ Types::CheckDNSAvailabilityResultMessage
Checks if the specified CNAME is available.
-
#compose_environments(params = {}) ⇒ Types::EnvironmentDescriptionsMessage
Create or update a group of environments that each run a separate component of a single application.
-
#create_application(params = {}) ⇒ Types::ApplicationDescriptionMessage
Creates an application that has one configuration template named
defaultand no application versions. -
#create_application_version(params = {}) ⇒ Types::ApplicationVersionDescriptionMessage
Creates an application version for the specified application.
-
#create_configuration_template(params = {}) ⇒ Types::ConfigurationSettingsDescription
Creates an Elastic Beanstalk configuration template, associated with a specific Elastic Beanstalk application.
-
#create_environment(params = {}) ⇒ Types::EnvironmentDescription
Launches an Elastic Beanstalk environment for the specified application using the specified configuration.
-
#create_platform_version(params = {}) ⇒ Types::CreatePlatformVersionResult
Create a new version of your custom platform.
-
#create_storage_location(params = {}) ⇒ Types::CreateStorageLocationResultMessage
Creates a bucket in Amazon S3 to store application versions, logs, and other files used by Elastic Beanstalk environments.
-
#delete_application(params = {}) ⇒ Struct
Deletes the specified application along with all associated versions and configurations.
-
#delete_application_version(params = {}) ⇒ Struct
Deletes the specified version from the specified application.
-
#delete_configuration_template(params = {}) ⇒ Struct
Deletes the specified configuration template.
-
#delete_environment_configuration(params = {}) ⇒ Struct
Deletes the draft configuration associated with the running environment.
-
#delete_platform_version(params = {}) ⇒ Types::DeletePlatformVersionResult
Deletes the specified version of a custom platform.
-
#describe_account_attributes(params = {}) ⇒ Types::DescribeAccountAttributesResult
Returns attributes related to Elastic Beanstalk that are associated with the calling Amazon Web Services account.
-
#describe_application_versions(params = {}) ⇒ Types::ApplicationVersionDescriptionsMessage
Retrieve a list of application versions.
-
#describe_applications(params = {}) ⇒ Types::ApplicationDescriptionsMessage
Returns the descriptions of existing applications.
-
#describe_configuration_options(params = {}) ⇒ Types::ConfigurationOptionsDescription
Describes the configuration options that are used in a particular configuration template or environment, or that a specified solution stack defines.
-
#describe_configuration_settings(params = {}) ⇒ Types::ConfigurationSettingsDescriptions
Returns a description of the settings for the specified configuration set, that is, either a configuration template or the configuration set associated with a running environment.
-
#describe_environment_health(params = {}) ⇒ Types::DescribeEnvironmentHealthResult
Returns information about the overall health of the specified environment.
-
#describe_environment_managed_action_history(params = {}) ⇒ Types::DescribeEnvironmentManagedActionHistoryResult
Lists an environment's completed and failed managed actions.
-
#describe_environment_managed_actions(params = {}) ⇒ Types::DescribeEnvironmentManagedActionsResult
Lists an environment's upcoming and in-progress managed actions.
-
#describe_environment_resources(params = {}) ⇒ Types::EnvironmentResourceDescriptionsMessage
Returns Amazon Web Services resources for this environment.
-
#describe_environments(params = {}) ⇒ Types::EnvironmentDescriptionsMessage
Returns descriptions for existing environments.
-
#describe_events(params = {}) ⇒ Types::EventDescriptionsMessage
Returns list of event descriptions matching criteria up to the last 6 weeks.
-
#describe_instances_health(params = {}) ⇒ Types::DescribeInstancesHealthResult
Retrieves detailed information about the health of instances in your Elastic Beanstalk environments.
-
#describe_platform_version(params = {}) ⇒ Types::DescribePlatformVersionResult
Describes a platform version.
-
#disassociate_environment_operations_role(params = {}) ⇒ Struct
The operations role feature of Elastic Beanstalk is in beta release and is subject to change.
-
#list_available_solution_stacks(params = {}) ⇒ Types::ListAvailableSolutionStacksResultMessage
Returns a list of the available solution stack names, with the public version first and then in reverse chronological order.
-
#list_platform_branches(params = {}) ⇒ Types::ListPlatformBranchesResult
Lists the platform branches available for your account in an Amazon Web Services Region.
-
#list_platform_versions(params = {}) ⇒ Types::ListPlatformVersionsResult
Lists the platform versions available for your account in an Amazon Web Services Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ResourceTagsDescriptionMessage
Return the tags applied to an Elastic Beanstalk resource.
-
#rebuild_environment(params = {}) ⇒ Struct
Deletes and recreates all of the Amazon Web Services resources (for example: the Auto Scaling group, load balancer, etc.) for a specified environment and forces a restart.
-
#request_environment_info(params = {}) ⇒ Struct
Initiates a request to compile the specified type of information of the deployed environment.
-
#restart_app_server(params = {}) ⇒ Struct
Causes the environment to restart the application container server running on each Amazon EC2 instance.
-
#retrieve_environment_info(params = {}) ⇒ Types::RetrieveEnvironmentInfoResultMessage
Retrieves the compiled information from a RequestEnvironmentInfo request.
-
#swap_environment_cnames(params = {}) ⇒ Struct
Swaps the CNAMEs of two environments.
-
#terminate_environment(params = {}) ⇒ Types::EnvironmentDescription
Terminates the specified environment.
-
#update_application(params = {}) ⇒ Types::ApplicationDescriptionMessage
Updates the specified application to have the specified properties.
-
#update_application_resource_lifecycle(params = {}) ⇒ Types::ApplicationResourceLifecycleDescriptionMessage
Modifies lifecycle settings for an application.
-
#update_application_version(params = {}) ⇒ Types::ApplicationVersionDescriptionMessage
Updates the specified application version to have the specified properties.
-
#update_configuration_template(params = {}) ⇒ Types::ConfigurationSettingsDescription
Updates the specified configuration template to have the specified properties or configuration option values.
-
#update_environment(params = {}) ⇒ Types::EnvironmentDescription
Updates the environment description, deploys a new application version, updates the configuration settings to an entirely new configuration template, or updates select configuration option values in the running environment.
-
#update_tags_for_resource(params = {}) ⇒ Struct
Update the list of tags applied to an Elastic Beanstalk resource.
-
#validate_configuration_settings(params = {}) ⇒ Types::ConfigurationSettingsValidationMessages
Takes a set of configuration settings and either a configuration template or environment, and determines whether those values are valid.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5176 5177 5178 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 5176 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5179 5180 5181 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 5179 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#abort_environment_update(params = {}) ⇒ Struct
Cancels in-progress environment configuration update or application version deployment.
82 |
# File 'sig/client.rbs', line 82 def abort_environment_update: ( |
#apply_environment_managed_action(params = {}) ⇒ Types::ApplyEnvironmentManagedActionResult
Applies a scheduled managed action immediately. A managed action can
be applied only if its status is Scheduled. Get the status and
action ID of a managed action with DescribeEnvironmentManagedActions.
96 |
# File 'sig/client.rbs', line 96 def apply_environment_managed_action: ( |
#associate_environment_operations_role(params = {}) ⇒ Struct
The operations role feature of Elastic Beanstalk is in beta release and is subject to change.
Add or change the operations role used by an environment. After this call is made, Elastic Beanstalk uses the associated operations role for permissions to downstream services during subsequent calls acting on this environment.
104 |
# File 'sig/client.rbs', line 104 def associate_environment_operations_role: ( |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5032 5033 5034 5035 5036 5037 5038 5039 5040 5041 5042 5043 5044 5045 5046 5047 5048 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 5032 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ElasticBeanstalk') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-elasticbeanstalk' context[:gem_version] = '1.109.0' Seahorse::Client::Request.new(handlers, context) end |
#check_dns_availability(params = {}) ⇒ Types::CheckDNSAvailabilityResultMessage
Checks if the specified CNAME is available.
116 |
# File 'sig/client.rbs', line 116 def check_dns_availability: ( |
#compose_environments(params = {}) ⇒ Types::EnvironmentDescriptionsMessage
Create or update a group of environments that each run a separate
component of a single application. Takes a list of version labels that
specify application source bundles for each of the environments to
create or update. The name of each environment and other required
information must be included in the source bundles in an environment
manifest named env.yaml. See Compose Environments for details.
127 |
# File 'sig/client.rbs', line 127 def compose_environments: ( |
#create_application(params = {}) ⇒ Types::ApplicationDescriptionMessage
Creates an application that has one configuration template named
default and no application versions.
139 |
# File 'sig/client.rbs', line 139 def create_application: ( |
#create_application_version(params = {}) ⇒ Types::ApplicationVersionDescriptionMessage
Creates an application version for the specified application. You can create an application version from a source bundle in Amazon S3, a commit in CodeCommit, or the output of an CodeBuild build as follows:
Specify a commit in an CodeCommit repository with
SourceBuildInformation.
Specify a build in an CodeBuild with SourceBuildInformation and
BuildConfiguration.
Specify a source bundle in Amazon S3 with SourceBundle
Omit both SourceBuildInformation and SourceBundle to use the
default sample application.
157 |
# File 'sig/client.rbs', line 157 def create_application_version: ( |
#create_configuration_template(params = {}) ⇒ Types::ConfigurationSettingsDescription
Creates an Elastic Beanstalk configuration template, associated with a specific Elastic Beanstalk application. You define application configuration settings in a configuration template. You can then use the configuration template to deploy different versions of the application with the same configuration settings.
Templates aren't associated with any environment. The
EnvironmentName response element is always null.
Related Topics
-
DescribeConfigurationOptions
-
DescribeConfigurationSettings
-
ListAvailableSolutionStacks
216 |
# File 'sig/client.rbs', line 216 def create_configuration_template: ( |
#create_environment(params = {}) ⇒ Types::EnvironmentDescription
Launches an Elastic Beanstalk environment for the specified application using the specified configuration.
269 |
# File 'sig/client.rbs', line 269 def create_environment: ( |
#create_platform_version(params = {}) ⇒ Types::CreatePlatformVersionResult
Create a new version of your custom platform.
315 |
# File 'sig/client.rbs', line 315 def create_platform_version: ( |
#create_storage_location(params = {}) ⇒ Types::CreateStorageLocationResultMessage
Creates a bucket in Amazon S3 to store application versions, logs, and
other files used by Elastic Beanstalk environments. The Elastic
Beanstalk console and EB CLI call this API the first time you create
an environment in a region. If the storage location already exists,
CreateStorageLocation still returns the bucket name but does not
create a new bucket.
345 346 |
# File 'sig/client.rbs', line 345 def create_storage_location: () -> _CreateStorageLocationResponseSuccess | (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] ) -> _CreateStorageLocationResponseSuccess |
#delete_application(params = {}) ⇒ Struct
Deletes the specified application along with all associated versions and configurations. The application versions will not be deleted from your Amazon S3 bucket.
349 |
# File 'sig/client.rbs', line 349 def delete_application: ( |
#delete_application_version(params = {}) ⇒ Struct
Deletes the specified version from the specified application.
356 |
# File 'sig/client.rbs', line 356 def delete_application_version: ( |
#delete_configuration_template(params = {}) ⇒ Struct
Deletes the specified configuration template.
364 |
# File 'sig/client.rbs', line 364 def delete_configuration_template: ( |
#delete_environment_configuration(params = {}) ⇒ Struct
Deletes the draft configuration associated with the running environment.
Updating a running environment with any configuration changes creates
a draft configuration set. You can get the draft configuration using
DescribeConfigurationSettings while the update is in progress or if
the update fails. The DeploymentStatus for the draft configuration
indicates whether the deployment is in process or has failed. The
draft configuration remains in existence until it is deleted with this
action.
371 |
# File 'sig/client.rbs', line 371 def delete_environment_configuration: ( |
#delete_platform_version(params = {}) ⇒ Types::DeletePlatformVersionResult
Deletes the specified version of a custom platform.
382 |
# File 'sig/client.rbs', line 382 def delete_platform_version: ( |
#describe_account_attributes(params = {}) ⇒ Types::DescribeAccountAttributesResult
Returns attributes related to Elastic Beanstalk that are associated with the calling Amazon Web Services account.
The result currently has one set of attributes—resource quotas.
This action only returns information about resources that the calling principle has IAM permissions to access. For example, consider a case where a user only has permission to access one of three resources. When the user calls the this action, the response will only include the one resource that the user has permission to access instead of all three resources. If the user doesn’t have access to any of the resources an empty result is returned.
392 393 |
# File 'sig/client.rbs', line 392 def describe_account_attributes: () -> _DescribeAccountAttributesResponseSuccess | (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] ) -> _DescribeAccountAttributesResponseSuccess |
#describe_application_versions(params = {}) ⇒ Types::ApplicationVersionDescriptionsMessage
Retrieve a list of application versions.
This action only returns information about resources that the calling principle has IAM permissions to access. For example, consider a case where a user only has permission to access one of three resources. When the user calls the this action, the response will only include the one resource that the user has permission to access instead of all three resources. If the user doesn’t have access to any of the resources an empty result is returned.
401 |
# File 'sig/client.rbs', line 401 def describe_application_versions: ( |
#describe_applications(params = {}) ⇒ Types::ApplicationDescriptionsMessage
Returns the descriptions of existing applications.
This action only returns information about applications that the calling principle has IAM permissions to access. For example, consider a case where a user only has permission to access two of three applications. When the user calls the DescribeApplications action, the response will only include the two applications that the user has permission to access instead of all three applications. If the user doesn’t have access to any of the applications an empty result is returned.
414 |
# File 'sig/client.rbs', line 414 def describe_applications: ( |
#describe_configuration_options(params = {}) ⇒ Types::ConfigurationOptionsDescription
Describes the configuration options that are used in a particular configuration template or environment, or that a specified solution stack defines. The description includes the values the options, their default values, and an indication of the required action on a running environment if an option value is changed.
This action only returns information about resources that the calling principle has IAM permissions to access. For example, consider a case where a user only has permission to access one of three resources. When the user calls the this action, the response will only include the one resource that the user has permission to access instead of all three resources. If the user doesn’t have access to any of the resources an empty result is returned.
426 |
# File 'sig/client.rbs', line 426 def describe_configuration_options: ( |
#describe_configuration_settings(params = {}) ⇒ Types::ConfigurationSettingsDescriptions
Returns a description of the settings for the specified configuration set, that is, either a configuration template or the configuration set associated with a running environment.
When describing the settings for the configuration set associated with a running environment, it is possible to receive two sets of setting descriptions. One is the deployed configuration set, and the other is a draft configuration of an environment that is either in the process of deployment or that failed to deploy.
This action only returns information about resources that the calling principle has IAM permissions to access. For example, consider a case where a user only has permission to access one of three resources. When the user calls the this action, the response will only include the one resource that the user has permission to access instead of all three resources. If the user doesn’t have access to any of the resources an empty result is returned.
Related Topics
- DeleteEnvironmentConfiguration
^
447 |
# File 'sig/client.rbs', line 447 def describe_configuration_settings: ( |
#describe_environment_health(params = {}) ⇒ Types::DescribeEnvironmentHealthResult
Returns information about the overall health of the specified environment. The DescribeEnvironmentHealth operation is only available with Elastic Beanstalk Enhanced Health.
This action only returns information about environments that the calling principle has IAM permissions to access. For example, consider a case where a user only has permission to access one of three environments. When the user calls this action, the response will only include the one environment that the user has permission to access instead of all three environments. If the user doesn’t have access to any of the environments an empty result is returned.
466 |
# File 'sig/client.rbs', line 466 def describe_environment_health: ( |
#describe_environment_managed_action_history(params = {}) ⇒ Types::DescribeEnvironmentManagedActionHistoryResult
Lists an environment's completed and failed managed actions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
479 |
# File 'sig/client.rbs', line 479 def describe_environment_managed_action_history: ( |
#describe_environment_managed_actions(params = {}) ⇒ Types::DescribeEnvironmentManagedActionsResult
Lists an environment's upcoming and in-progress managed actions.
This action only returns information about environments that the calling principle has IAM permissions to access. For example, consider a case where a user only has permission to access one of three environments. When the user calls this action, the response will only include the one environment that the user has permission to access instead of all three environments. If the user doesn’t have access to any of the environments an empty result is returned.
492 |
# File 'sig/client.rbs', line 492 def describe_environment_managed_actions: ( |
#describe_environment_resources(params = {}) ⇒ Types::EnvironmentResourceDescriptionsMessage
Returns Amazon Web Services resources for this environment.
504 |
# File 'sig/client.rbs', line 504 def describe_environment_resources: ( |
#describe_environments(params = {}) ⇒ Types::EnvironmentDescriptionsMessage
Returns descriptions for existing environments.
This action only returns information about environments that the calling principle has IAM permissions to access. For example, consider a case where a user only has permission to access one of three environments. When the user calls the DescribeEnvironments action, the response will only include the one environment that the user has permission to access instead of all three environments. If the user doesn’t have access to any of the environments an empty result is returned.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* environment_exists
* environment_terminated
* environment_updated
516 |
# File 'sig/client.rbs', line 516 def describe_environments: ( |
#describe_events(params = {}) ⇒ Types::EventDescriptionsMessage
Returns list of event descriptions matching criteria up to the last 6 weeks.
This action returns the most recent 1,000 events from the specified
NextToken.
This action only returns information about resources that the calling principle has IAM permissions to access. For example, consider a case where a user only has permission to access one of three resources. When the user calls the this action, the response will only include the one resource that the user has permission to access instead of all three resources. If the user doesn’t have access to any of the resources an empty result is returned.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
534 |
# File 'sig/client.rbs', line 534 def describe_events: ( |
#describe_instances_health(params = {}) ⇒ Types::DescribeInstancesHealthResult
Retrieves detailed information about the health of instances in your Elastic Beanstalk environments. This operation requires enhanced health reporting.
This action only returns information about environments that the calling principle has IAM permissions to access. For example, consider a case where a user only has permission to access one of three environments. When the user calls this action, the response will only include the one environment that the user has permission to access instead of all three environments. If the user doesn’t have access to any of the environments an empty result is returned.
557 |
# File 'sig/client.rbs', line 557 def describe_instances_health: ( |
#describe_platform_version(params = {}) ⇒ Types::DescribePlatformVersionResult
Describes a platform version. Provides full details. Compare to ListPlatformVersions, which provides summary information about a list of platform versions.
For definitions of platform version and other platform-related terms, see Elastic Beanstalk Platforms Glossary.
This action only returns information about resources that the calling principle has IAM permissions to access. For example, consider a case where a user only has permission to access one of three resources. When the user calls the this action, the response will only include the one resource that the user has permission to access instead of all three resources. If the user doesn’t have access to any of the resources an empty result is returned.
570 |
# File 'sig/client.rbs', line 570 def describe_platform_version: ( |
#disassociate_environment_operations_role(params = {}) ⇒ Struct
The operations role feature of Elastic Beanstalk is in beta release and is subject to change.
Disassociate the operations role from an environment. After this call is made, Elastic Beanstalk uses the caller's permissions for permissions to downstream services during subsequent calls acting on this environment.
576 |
# File 'sig/client.rbs', line 576 def disassociate_environment_operations_role: ( |
#list_available_solution_stacks(params = {}) ⇒ Types::ListAvailableSolutionStacksResultMessage
Returns a list of the available solution stack names, with the public version first and then in reverse chronological order.
This action only returns information about resources that the calling principle has IAM permissions to access. For example, consider a case where a user only has permission to access one of three resources. When the user calls the this action, the response will only include the one resource that the user has permission to access instead of all three resources. If the user doesn’t have access to any of the resources an empty result is returned.
587 588 |
# File 'sig/client.rbs', line 587 def list_available_solution_stacks: () -> _ListAvailableSolutionStacksResponseSuccess | (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] ) -> _ListAvailableSolutionStacksResponseSuccess |
#list_platform_branches(params = {}) ⇒ Types::ListPlatformBranchesResult
Lists the platform branches available for your account in an Amazon Web Services Region. Provides summary information about each platform branch.
For definitions of platform branch and other platform-related terms, see Elastic Beanstalk Platforms Glossary.
This action only returns information about resources that the calling principle has IAM permissions to access. For example, consider a case where a user only has permission to access one of three resources. When the user calls the this action, the response will only include the one resource that the user has permission to access instead of all three resources. If the user doesn’t have access to any of the resources an empty result is returned.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
596 |
# File 'sig/client.rbs', line 596 def list_platform_branches: ( |
#list_platform_versions(params = {}) ⇒ Types::ListPlatformVersionsResult
Lists the platform versions available for your account in an Amazon Web Services Region. Provides summary information about each platform version. Compare to DescribePlatformVersion, which provides full details about a single platform version.
This action only returns information about platform versions that the calling principle has IAM permissions to access. For example, consider a case where a user only has permission to access one of ten platform versions. When the user calls the ListPlatformVersions action, the response will only include the one platform version that the user has permission to access instead of all ten platform versions. If the user doesn’t have access to any of the platform versions an empty result is returned.
For definitions of platform version and other platform-related terms, see Elastic Beanstalk Platforms Glossary.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
615 |
# File 'sig/client.rbs', line 615 def list_platform_versions: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ResourceTagsDescriptionMessage
Return the tags applied to an Elastic Beanstalk resource. The response contains a list of tag key-value pairs.
Elastic Beanstalk supports tagging of all of its resources. For details about resource tagging, see Tagging Application Resources.
This action only returns information about resources that the calling principle has IAM permissions to access. For example, consider a case where a user only has permission to access one of three resources. When the user calls the this action, the response will only include the one resource that the user has permission to access instead of all three resources. If the user doesn’t have access to any of the resources an empty result is returned.
634 |
# File 'sig/client.rbs', line 634 def list_tags_for_resource: ( |
#rebuild_environment(params = {}) ⇒ Struct
Deletes and recreates all of the Amazon Web Services resources (for example: the Auto Scaling group, load balancer, etc.) for a specified environment and forces a restart.
640 |
# File 'sig/client.rbs', line 640 def rebuild_environment: ( |
#request_environment_info(params = {}) ⇒ Struct
Initiates a request to compile the specified type of information of the deployed environment.
Setting the InfoType to tail compiles the last lines from the
application server log files of every Amazon EC2 instance in your
environment.
Setting the InfoType to bundle compresses the application server
log files for every Amazon EC2 instance into a .zip file. Legacy and
.NET containers do not support bundle logs.
Setting the InfoType to analyze collects recent events, instance
health, and logs from your environment and sends them to Amazon
Bedrock in your account to generate diagnostic insights and
recommended next steps.
Use RetrieveEnvironmentInfo to obtain the set of logs.
Related Topics
- RetrieveEnvironmentInfo
^
647 |
# File 'sig/client.rbs', line 647 def request_environment_info: ( |
#restart_app_server(params = {}) ⇒ Struct
Causes the environment to restart the application container server running on each Amazon EC2 instance.
655 |
# File 'sig/client.rbs', line 655 def restart_app_server: ( |
#retrieve_environment_info(params = {}) ⇒ Types::RetrieveEnvironmentInfoResultMessage
Retrieves the compiled information from a RequestEnvironmentInfo request.
Related Topics
- RequestEnvironmentInfo
^
666 |
# File 'sig/client.rbs', line 666 def retrieve_environment_info: ( |
#swap_environment_cnames(params = {}) ⇒ Struct
Swaps the CNAMEs of two environments.
674 |
# File 'sig/client.rbs', line 674 def swap_environment_cnames: ( |
#terminate_environment(params = {}) ⇒ Types::EnvironmentDescription
Terminates the specified environment.
707 |
# File 'sig/client.rbs', line 707 def terminate_environment: ( |
#update_application(params = {}) ⇒ Types::ApplicationDescriptionMessage
Updates the specified application to have the specified properties.
description) is not provided, the value
remains unchanged. To clear these properties, specify an empty string.
720 |
# File 'sig/client.rbs', line 720 def update_application: ( |
#update_application_resource_lifecycle(params = {}) ⇒ Types::ApplicationResourceLifecycleDescriptionMessage
Modifies lifecycle settings for an application.
732 |
# File 'sig/client.rbs', line 732 def update_application_resource_lifecycle: ( |
#update_application_version(params = {}) ⇒ Types::ApplicationVersionDescriptionMessage
Updates the specified application version to have the specified properties.
description) is not provided, the value
remains unchanged. To clear properties, specify an empty string.
743 |
# File 'sig/client.rbs', line 743 def update_application_version: ( |
#update_configuration_template(params = {}) ⇒ Types::ConfigurationSettingsDescription
Updates the specified configuration template to have the specified properties or configuration option values.
ApplicationName) is not provided, its
value remains unchanged. To clear such properties, specify an empty
string.
Related Topics
- DescribeConfigurationOptions
^
764 |
# File 'sig/client.rbs', line 764 def update_configuration_template: ( |
#update_environment(params = {}) ⇒ Types::EnvironmentDescription
Updates the environment description, deploys a new application version, updates the configuration settings to an entirely new configuration template, or updates select configuration option values in the running environment.
Attempting to update both the release and configuration is not allowed
and Elastic Beanstalk returns an InvalidParameterCombination error.
When updating the configuration settings to a new template or
individual settings, a draft configuration is created and
DescribeConfigurationSettings for this environment returns two setting
descriptions with different DeploymentStatus values.
811 |
# File 'sig/client.rbs', line 811 def update_environment: ( |
#update_tags_for_resource(params = {}) ⇒ Struct
Update the list of tags applied to an Elastic Beanstalk resource. Two
lists can be passed: TagsToAdd for tags to add or update, and
TagsToRemove.
Elastic Beanstalk supports tagging of all of its resources. For details about resource tagging, see Tagging Application Resources.
If you create a custom policy to control permission to this operation, specify one of the following two virtual actions (or both) instead of the API operation name:
elasticbeanstalk:AddTags
: Controls permission to call UpdateTagsForResource and pass a list
of tags to add in the TagsToAdd parameter.
elasticbeanstalk:RemoveTags
: Controls permission to call UpdateTagsForResource and pass a list
of tag keys to remove in the TagsToRemove parameter.
For details about creating a custom user policy, see Creating a Custom User Policy.
845 |
# File 'sig/client.rbs', line 845 def update_tags_for_resource: ( |
#validate_configuration_settings(params = {}) ⇒ Types::ConfigurationSettingsValidationMessages
Takes a set of configuration settings and either a configuration template or environment, and determines whether those values are valid.
This action returns a list of messages indicating any errors or warnings associated with the selection of option values.
862 |
# File 'sig/client.rbs', line 862 def validate_configuration_settings: ( |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
Basic Usage
A waiter will call an API operation until:
- It is successful
- It enters a terminal state
- It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
Valid Waiters
The following table lists the valid waiter names, the operations they call,
and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts |
|---|---|---|---|
| environment_exists | #describe_environments | 20 | 20 |
| environment_terminated | #describe_environments | 20 | 20 |
| environment_updated | #describe_environments | 20 | 20 |
878 |
# File 'sig/client.rbs', line 878 def wait_until: (:environment_exists waiter_name, |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5148 5149 5150 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 5148 def waiter_names waiters.keys end |