Class: Aws::ElasticBeanstalk::Types::ApplicationVersionLifecycleConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::ApplicationVersionLifecycleConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
The application version lifecycle settings for an application. Defines the rules that Elastic Beanstalk applies to an application's versions in order to avoid hitting the per-region limit for application versions.
When Elastic Beanstalk deletes an application version from its database, you can no longer deploy that version to an environment. The source bundle remains in S3 unless you configure the rule to delete it.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_age_rule ⇒ Types::MaxAgeRule
Specify a max age rule to restrict the length of time that application versions are retained for an application.
-
#max_count_rule ⇒ Types::MaxCountRule
Specify a max count rule to restrict the number of application versions that are retained for an application.
Instance Attribute Details
#max_age_rule ⇒ Types::MaxAgeRule
Specify a max age rule to restrict the length of time that application versions are retained for an application.
362 363 364 365 366 367 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 362 class ApplicationVersionLifecycleConfig < Struct.new( :max_count_rule, :max_age_rule) SENSITIVE = [] include Aws::Structure end |
#max_count_rule ⇒ Types::MaxCountRule
Specify a max count rule to restrict the number of application versions that are retained for an application.
362 363 364 365 366 367 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 362 class ApplicationVersionLifecycleConfig < Struct.new( :max_count_rule, :max_age_rule) SENSITIVE = [] include Aws::Structure end |