Class: Aws::ElasticBeanstalk::Types::BuildConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::BuildConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Settings for an CodeBuild build.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#artifact_name ⇒ String
The name of the artifact of the CodeBuild build.
-
#code_build_service_role ⇒ String
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that enables CodeBuild to interact with dependent Amazon Web Services service on behalf of the Amazon Web Services account.
-
#compute_type ⇒ String
Information about the compute resources the build project will use.
-
#image ⇒ String
The ID of the Docker image to use for this build project.
-
#timeout_in_minutes ⇒ Integer
How long in minutes, from 5 to 480 (8 hours), for CodeBuild to wait until timing out any related build that does not get marked as completed.
Instance Attribute Details
#artifact_name ⇒ String
The name of the artifact of the CodeBuild build. If provided, Elastic Beanstalk stores the build artifact in the S3 location S3-bucket/resources/application-name/codebuild/codebuild-version-label-artifact-name.zip. If not provided, Elastic Beanstalk stores the build artifact in the S3 location S3-bucket/resources/application-name/codebuild/codebuild-version-label.zip.
498 499 500 501 502 503 504 505 506 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 498 class BuildConfiguration < Struct.new( :artifact_name, :code_build_service_role, :compute_type, :image, :timeout_in_minutes) SENSITIVE = [] include Aws::Structure end |
#code_build_service_role ⇒ String
The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that enables CodeBuild to interact with dependent Amazon Web Services service on behalf of the Amazon Web Services account.
498 499 500 501 502 503 504 505 506 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 498 class BuildConfiguration < Struct.new( :artifact_name, :code_build_service_role, :compute_type, :image, :timeout_in_minutes) SENSITIVE = [] include Aws::Structure end |
#compute_type ⇒ String
Information about the compute resources the build project will use.
-
BUILD_GENERAL1_SMALL: Use up to 3 GB memory and 2 vCPUs for builds -
BUILD_GENERAL1_MEDIUM: Use up to 7 GB memory and 4 vCPUs for builds -
BUILD_GENERAL1_LARGE: Use up to 15 GB memory and 8 vCPUs for builds
498 499 500 501 502 503 504 505 506 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 498 class BuildConfiguration < Struct.new( :artifact_name, :code_build_service_role, :compute_type, :image, :timeout_in_minutes) SENSITIVE = [] include Aws::Structure end |
#image ⇒ String
The ID of the Docker image to use for this build project.
498 499 500 501 502 503 504 505 506 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 498 class BuildConfiguration < Struct.new( :artifact_name, :code_build_service_role, :compute_type, :image, :timeout_in_minutes) SENSITIVE = [] include Aws::Structure end |
#timeout_in_minutes ⇒ Integer
How long in minutes, from 5 to 480 (8 hours), for CodeBuild to wait until timing out any related build that does not get marked as completed. The default is 60 minutes.
498 499 500 501 502 503 504 505 506 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 498 class BuildConfiguration < Struct.new( :artifact_name, :code_build_service_role, :compute_type, :image, :timeout_in_minutes) SENSITIVE = [] include Aws::Structure end |