Class: Aws::ElasticBeanstalk::Types::CPUUtilization

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticbeanstalk/types.rb

Overview

CPU utilization metrics for an instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idleFloat

Percentage of time that the CPU has spent in the Idle state over the last 10 seconds.



578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 578

class CPUUtilization < Struct.new(
  :user,
  :nice,
  :system,
  :idle,
  :io_wait,
  :irq,
  :soft_irq,
  :privileged)
  SENSITIVE = []
  include Aws::Structure
end

#io_waitFloat

Available on Linux environments only.

Percentage of time that the CPU has spent in the I/O Wait state over the last 10 seconds.



578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 578

class CPUUtilization < Struct.new(
  :user,
  :nice,
  :system,
  :idle,
  :io_wait,
  :irq,
  :soft_irq,
  :privileged)
  SENSITIVE = []
  include Aws::Structure
end

#irqFloat

Available on Linux environments only.

Percentage of time that the CPU has spent in the IRQ state over the last 10 seconds.



578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 578

class CPUUtilization < Struct.new(
  :user,
  :nice,
  :system,
  :idle,
  :io_wait,
  :irq,
  :soft_irq,
  :privileged)
  SENSITIVE = []
  include Aws::Structure
end

#niceFloat

Available on Linux environments only.

Percentage of time that the CPU has spent in the Nice state over the last 10 seconds.



578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 578

class CPUUtilization < Struct.new(
  :user,
  :nice,
  :system,
  :idle,
  :io_wait,
  :irq,
  :soft_irq,
  :privileged)
  SENSITIVE = []
  include Aws::Structure
end

#privilegedFloat

Available on Windows environments only.

Percentage of time that the CPU has spent in the Privileged state over the last 10 seconds.



578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 578

class CPUUtilization < Struct.new(
  :user,
  :nice,
  :system,
  :idle,
  :io_wait,
  :irq,
  :soft_irq,
  :privileged)
  SENSITIVE = []
  include Aws::Structure
end

#soft_irqFloat

Available on Linux environments only.

Percentage of time that the CPU has spent in the SoftIRQ state over the last 10 seconds.



578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 578

class CPUUtilization < Struct.new(
  :user,
  :nice,
  :system,
  :idle,
  :io_wait,
  :irq,
  :soft_irq,
  :privileged)
  SENSITIVE = []
  include Aws::Structure
end

#systemFloat

Available on Linux environments only.

Percentage of time that the CPU has spent in the System state over the last 10 seconds.



578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 578

class CPUUtilization < Struct.new(
  :user,
  :nice,
  :system,
  :idle,
  :io_wait,
  :irq,
  :soft_irq,
  :privileged)
  SENSITIVE = []
  include Aws::Structure
end

#userFloat

Percentage of time that the CPU has spent in the User state over the last 10 seconds.



578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 578

class CPUUtilization < Struct.new(
  :user,
  :nice,
  :system,
  :idle,
  :io_wait,
  :irq,
  :soft_irq,
  :privileged)
  SENSITIVE = []
  include Aws::Structure
end