Class: Aws::ElasticBeanstalk::Types::CreateApplicationMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::CreateApplicationMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Request to create an application.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of the application.
-
#description ⇒ String
Your description of the application.
-
#resource_lifecycle_config ⇒ Types::ApplicationResourceLifecycleConfig
Specifies an application resource lifecycle configuration to prevent your application from accumulating too many versions.
-
#tags ⇒ Array<Types::Tag>
Specifies the tags applied to the application.
Instance Attribute Details
#application_name ⇒ String
The name of the application. Must be unique within your account.
986 987 988 989 990 991 992 993 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 986 class CreateApplicationMessage < Struct.new( :application_name, :description, :resource_lifecycle_config, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Your description of the application.
986 987 988 989 990 991 992 993 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 986 class CreateApplicationMessage < Struct.new( :application_name, :description, :resource_lifecycle_config, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_lifecycle_config ⇒ Types::ApplicationResourceLifecycleConfig
Specifies an application resource lifecycle configuration to prevent your application from accumulating too many versions.
986 987 988 989 990 991 992 993 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 986 class CreateApplicationMessage < Struct.new( :application_name, :description, :resource_lifecycle_config, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Specifies the tags applied to the application.
Elastic Beanstalk applies these tags only to the application. Environments that you create in the application don't inherit the tags.
986 987 988 989 990 991 992 993 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 986 class CreateApplicationMessage < Struct.new( :application_name, :description, :resource_lifecycle_config, :tags) SENSITIVE = [] include Aws::Structure end |