Class: Aws::ElasticBeanstalk::Types::CreateApplicationVersionMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticbeanstalk/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_nameString

The name of the application. If no application is found with this name, and AutoCreateApplication is false, returns an InvalidParameterValue error.

Returns:

  • (String)


1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1091

class CreateApplicationVersionMessage < Struct.new(
  :application_name,
  :version_label,
  :description,
  :source_build_information,
  :source_bundle,
  :build_configuration,
  :auto_create_application,
  :process,
  :tags,
  :image_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#auto_create_applicationBoolean

Set to true to create an application with the specified name if it doesn't already exist.

Returns:

  • (Boolean)


1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1091

class CreateApplicationVersionMessage < Struct.new(
  :application_name,
  :version_label,
  :description,
  :source_build_information,
  :source_bundle,
  :build_configuration,
  :auto_create_application,
  :process,
  :tags,
  :image_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#build_configurationTypes::BuildConfiguration

Settings for an CodeBuild build.

Don't specify BuildConfiguration together with ImageConfiguration, which configures a container image build instead.



1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1091

class CreateApplicationVersionMessage < Struct.new(
  :application_name,
  :version_label,
  :description,
  :source_build_information,
  :source_bundle,
  :build_configuration,
  :auto_create_application,
  :process,
  :tags,
  :image_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of this application version.

Returns:

  • (String)


1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1091

class CreateApplicationVersionMessage < Struct.new(
  :application_name,
  :version_label,
  :description,
  :source_build_information,
  :source_bundle,
  :build_configuration,
  :auto_create_application,
  :process,
  :tags,
  :image_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#image_configurationTypes::ImageConfiguration

The source of the container image for this application version. You can specify an image that you built and pushed to a container registry yourself, or settings for Elastic Beanstalk to build one from your source bundle. Specify exactly one of the Source and Build members.

Don't specify ImageConfiguration together with BuildConfiguration, which configures an CodeBuild build instead.



1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1091

class CreateApplicationVersionMessage < Struct.new(
  :application_name,
  :version_label,
  :description,
  :source_build_information,
  :source_bundle,
  :build_configuration,
  :auto_create_application,
  :process,
  :tags,
  :image_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#processBoolean

Pre-processes and validates the environment manifest (env.yaml) and configuration files (*.config files in the .ebextensions folder) in the source bundle. Validating configuration files can identify issues prior to deploying the application version to an environment.

You must turn processing on for application versions that you create using CodeBuild or CodeCommit. For application versions built from a source bundle in Amazon S3, processing is optional.

The Process option validates Elastic Beanstalk configuration files. It doesn't validate your application's configuration files, like proxy server or Docker configuration.

Returns:

  • (Boolean)


1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1091

class CreateApplicationVersionMessage < Struct.new(
  :application_name,
  :version_label,
  :description,
  :source_build_information,
  :source_bundle,
  :build_configuration,
  :auto_create_application,
  :process,
  :tags,
  :image_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#source_build_informationTypes::SourceBuildInformation

Specify a commit in an CodeCommit Git repository to use as the source code for the application version.



1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1091

class CreateApplicationVersionMessage < Struct.new(
  :application_name,
  :version_label,
  :description,
  :source_build_information,
  :source_bundle,
  :build_configuration,
  :auto_create_application,
  :process,
  :tags,
  :image_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#source_bundleTypes::S3Location

The Amazon S3 bucket and key that identify the location of the source bundle for this version.

The Amazon S3 bucket must be in the same region as the environment.

Unless you're specifying a source bundle in the bucket that Elastic Beanstalk manages in your account, you must assign a custom policy to your user, and grant Allow permission to the s3:Get* actions on your S3 object resource, for example, arn:aws:s3:::your-bucket/your-source-bundle-object.

Specify a source bundle in Amazon S3 or a commit in an CodeCommit repository (with SourceBuildInformation), but not both. If neither SourceBundle nor SourceBuildInformation are provided, Elastic Beanstalk uses a sample application.

Returns:



1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1091

class CreateApplicationVersionMessage < Struct.new(
  :application_name,
  :version_label,
  :description,
  :source_build_information,
  :source_bundle,
  :build_configuration,
  :auto_create_application,
  :process,
  :tags,
  :image_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Specifies the tags applied to the application version.

Elastic Beanstalk applies these tags only to the application version. Environments that use the application version don't inherit the tags.

Returns:



1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1091

class CreateApplicationVersionMessage < Struct.new(
  :application_name,
  :version_label,
  :description,
  :source_build_information,
  :source_bundle,
  :build_configuration,
  :auto_create_application,
  :process,
  :tags,
  :image_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#version_labelString

A label identifying this version.

Constraint: Must be unique per application. If an application version already exists with this label for the specified application, Elastic Beanstalk returns an InvalidParameterValue error.

Returns:

  • (String)


1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1091

class CreateApplicationVersionMessage < Struct.new(
  :application_name,
  :version_label,
  :description,
  :source_build_information,
  :source_bundle,
  :build_configuration,
  :auto_create_application,
  :process,
  :tags,
  :image_configuration)
  SENSITIVE = []
  include Aws::Structure
end