Class: Aws::ElasticBeanstalk::Types::CreatePlatformVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticbeanstalk/types.rb

Overview

Request to create a new platform version.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#environment_nameString

The name of the builder environment.

Returns:



1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1396

class CreatePlatformVersionRequest < Struct.new(
  :platform_name,
  :platform_version,
  :platform_definition_bundle,
  :environment_name,
  :option_settings,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#option_settingsArray<Types::ConfigurationOptionSetting>

The configuration option settings to apply to the builder environment.

Returns:



1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1396

class CreatePlatformVersionRequest < Struct.new(
  :platform_name,
  :platform_version,
  :platform_definition_bundle,
  :environment_name,
  :option_settings,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#platform_definition_bundleTypes::S3Location

The location of the platform definition archive in Amazon S3.

Returns:



1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1396

class CreatePlatformVersionRequest < Struct.new(
  :platform_name,
  :platform_version,
  :platform_definition_bundle,
  :environment_name,
  :option_settings,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#platform_nameString

The name of your custom platform.

Returns:



1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1396

class CreatePlatformVersionRequest < Struct.new(
  :platform_name,
  :platform_version,
  :platform_definition_bundle,
  :environment_name,
  :option_settings,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#platform_versionString

The number, such as 1.0.2, for the new platform version.

Returns:



1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1396

class CreatePlatformVersionRequest < Struct.new(
  :platform_name,
  :platform_version,
  :platform_definition_bundle,
  :environment_name,
  :option_settings,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

Specifies the tags applied to the new platform version.

Elastic Beanstalk applies these tags only to the platform version. Environments that you create using the platform version don't inherit the tags.

Returns:



1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1396

class CreatePlatformVersionRequest < Struct.new(
  :platform_name,
  :platform_version,
  :platform_definition_bundle,
  :environment_name,
  :option_settings,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end