Class: Aws::ElasticBeanstalk::Types::CreatePlatformVersionResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::CreatePlatformVersionResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#builder ⇒ Types::Builder
The builder used to create the custom platform.
-
#platform_summary ⇒ Types::PlatformSummary
Detailed information about the new version of the custom platform.
Instance Attribute Details
#builder ⇒ Types::Builder
The builder used to create the custom platform.
1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1417 class CreatePlatformVersionResult < Struct.new( :platform_summary, :builder) SENSITIVE = [] include Aws::Structure end |
#platform_summary ⇒ Types::PlatformSummary
Detailed information about the new version of the custom platform.
1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1417 class CreatePlatformVersionResult < Struct.new( :platform_summary, :builder) SENSITIVE = [] include Aws::Structure end |