Class: Aws::ElasticBeanstalk::Types::DeleteConfigurationTemplateMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::DeleteConfigurationTemplateMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Request to delete a configuration template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of the application to delete the configuration template from.
-
#template_name ⇒ String
The name of the configuration template to delete.
Instance Attribute Details
#application_name ⇒ String
The name of the application to delete the configuration template from.
1516 1517 1518 1519 1520 1521 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1516 class DeleteConfigurationTemplateMessage < Struct.new( :application_name, :template_name) SENSITIVE = [] include Aws::Structure end |
#template_name ⇒ String
The name of the configuration template to delete.
1516 1517 1518 1519 1520 1521 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1516 class DeleteConfigurationTemplateMessage < Struct.new( :application_name, :template_name) SENSITIVE = [] include Aws::Structure end |