Class: Aws::ElasticBeanstalk::Types::DeletePlatformVersionResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::DeletePlatformVersionResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#platform_summary ⇒ Types::PlatformSummary
Detailed information about the version of the custom platform.
Instance Attribute Details
#platform_summary ⇒ Types::PlatformSummary
Detailed information about the version of the custom platform.
1560 1561 1562 1563 1564 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1560 class DeletePlatformVersionResult < Struct.new( :platform_summary) SENSITIVE = [] include Aws::Structure end |