Class: Aws::ElasticBeanstalk::Types::DescribeApplicationVersionsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::DescribeApplicationVersionsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Request to describe application versions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
Specify an application name to show only application versions for that application.
-
#max_records ⇒ Integer
For a paginated request.
-
#next_token ⇒ String
For a paginated request.
-
#version_labels ⇒ Array<String>
Specify a version label to show a specific application version.
Instance Attribute Details
#application_name ⇒ String
Specify an application name to show only application versions for that application.
1647 1648 1649 1650 1651 1652 1653 1654 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1647 class DescribeApplicationVersionsMessage < Struct.new( :application_name, :version_labels, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
For a paginated request. Specify a maximum number of application versions to include in each response.
If no MaxRecords is specified, all available application versions
are retrieved in a single response.
1647 1648 1649 1650 1651 1652 1653 1654 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1647 class DescribeApplicationVersionsMessage < Struct.new( :application_name, :version_labels, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
For a paginated request. Specify a token from a previous response page to retrieve the next response page. All other parameter values must be identical to the ones specified in the initial request.
If no NextToken is specified, the first page is retrieved.
1647 1648 1649 1650 1651 1652 1653 1654 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1647 class DescribeApplicationVersionsMessage < Struct.new( :application_name, :version_labels, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#version_labels ⇒ Array<String>
Specify a version label to show a specific application version.
1647 1648 1649 1650 1651 1652 1653 1654 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1647 class DescribeApplicationVersionsMessage < Struct.new( :application_name, :version_labels, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |