Class: Aws::ElasticBeanstalk::Types::DescribeApplicationsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::DescribeApplicationsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Request to describe one or more applications.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_names ⇒ Array<String>
If specified, Elastic Beanstalk restricts the returned descriptions to only include those with the specified names.
Instance Attribute Details
#application_names ⇒ Array<String>
If specified, Elastic Beanstalk restricts the returned descriptions to only include those with the specified names.
1665 1666 1667 1668 1669 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1665 class DescribeApplicationsMessage < Struct.new( :application_names) SENSITIVE = [] include Aws::Structure end |