Class: Aws::ElasticBeanstalk::Types::DescribeConfigurationOptionsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticbeanstalk/types.rb

Overview

Result message containing a list of application version descriptions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_nameString

The name of the application associated with the configuration template or environment. Only needed if you want to describe the configuration options associated with either the configuration template or environment.

Returns:

  • (String)


1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1706

class DescribeConfigurationOptionsMessage < Struct.new(
  :application_name,
  :template_name,
  :environment_name,
  :solution_stack_name,
  :platform_arn,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#environment_nameString

The name of the environment whose configuration options you want to describe.

Returns:

  • (String)


1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1706

class DescribeConfigurationOptionsMessage < Struct.new(
  :application_name,
  :template_name,
  :environment_name,
  :solution_stack_name,
  :platform_arn,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#optionsArray<Types::OptionSpecification>

If specified, restricts the descriptions to only the specified options.

Returns:



1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1706

class DescribeConfigurationOptionsMessage < Struct.new(
  :application_name,
  :template_name,
  :environment_name,
  :solution_stack_name,
  :platform_arn,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#platform_arnString

The ARN of the custom platform.

Returns:

  • (String)


1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1706

class DescribeConfigurationOptionsMessage < Struct.new(
  :application_name,
  :template_name,
  :environment_name,
  :solution_stack_name,
  :platform_arn,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#solution_stack_nameString

The name of the solution stack whose configuration options you want to describe.

Returns:

  • (String)


1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1706

class DescribeConfigurationOptionsMessage < Struct.new(
  :application_name,
  :template_name,
  :environment_name,
  :solution_stack_name,
  :platform_arn,
  :options)
  SENSITIVE = []
  include Aws::Structure
end

#template_nameString

The name of the configuration template whose configuration options you want to describe.

Returns:

  • (String)


1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1706

class DescribeConfigurationOptionsMessage < Struct.new(
  :application_name,
  :template_name,
  :environment_name,
  :solution_stack_name,
  :platform_arn,
  :options)
  SENSITIVE = []
  include Aws::Structure
end