Class: Aws::ElasticBeanstalk::Types::DescribeEnvironmentHealthResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::DescribeEnvironmentHealthResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Health details for an Elastic Beanstalk environment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_metrics ⇒ Types::ApplicationMetrics
Application request metrics for the environment.
-
#causes ⇒ Array<String>
Descriptions of the data that contributed to the environment's current health status.
-
#color ⇒ String
The [health color][1] of the environment.
-
#environment_name ⇒ String
The environment's name.
-
#health_status ⇒ String
The [health status][1] of the environment.
-
#instances_health ⇒ Types::InstanceHealthSummary
Summary health information for the instances in the environment.
-
#refreshed_at ⇒ Time
The date and time that the health information was retrieved.
-
#status ⇒ String
The environment's operational status.
Instance Attribute Details
#application_metrics ⇒ Types::ApplicationMetrics
Application request metrics for the environment.
1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1829 class DescribeEnvironmentHealthResult < Struct.new( :environment_name, :health_status, :status, :color, :causes, :application_metrics, :instances_health, :refreshed_at) SENSITIVE = [] include Aws::Structure end |
#causes ⇒ Array<String>
Descriptions of the data that contributed to the environment's current health status.
1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1829 class DescribeEnvironmentHealthResult < Struct.new( :environment_name, :health_status, :status, :color, :causes, :application_metrics, :instances_health, :refreshed_at) SENSITIVE = [] include Aws::Structure end |
#color ⇒ String
The health color of the environment.
1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1829 class DescribeEnvironmentHealthResult < Struct.new( :environment_name, :health_status, :status, :color, :causes, :application_metrics, :instances_health, :refreshed_at) SENSITIVE = [] include Aws::Structure end |
#environment_name ⇒ String
The environment's name.
1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1829 class DescribeEnvironmentHealthResult < Struct.new( :environment_name, :health_status, :status, :color, :causes, :application_metrics, :instances_health, :refreshed_at) SENSITIVE = [] include Aws::Structure end |
#health_status ⇒ String
The health status of the environment. For example, Ok.
1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1829 class DescribeEnvironmentHealthResult < Struct.new( :environment_name, :health_status, :status, :color, :causes, :application_metrics, :instances_health, :refreshed_at) SENSITIVE = [] include Aws::Structure end |
#instances_health ⇒ Types::InstanceHealthSummary
Summary health information for the instances in the environment.
1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1829 class DescribeEnvironmentHealthResult < Struct.new( :environment_name, :health_status, :status, :color, :causes, :application_metrics, :instances_health, :refreshed_at) SENSITIVE = [] include Aws::Structure end |
#refreshed_at ⇒ Time
The date and time that the health information was retrieved.
1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1829 class DescribeEnvironmentHealthResult < Struct.new( :environment_name, :health_status, :status, :color, :causes, :application_metrics, :instances_health, :refreshed_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The environment's operational status. Ready, Launching,
Updating, Terminating, or Terminated.
1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1829 class DescribeEnvironmentHealthResult < Struct.new( :environment_name, :health_status, :status, :color, :causes, :application_metrics, :instances_health, :refreshed_at) SENSITIVE = [] include Aws::Structure end |