Class: Aws::ElasticBeanstalk::Types::DescribeEnvironmentsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::DescribeEnvironmentsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Request to describe one or more environments.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
If specified, Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application.
-
#environment_ids ⇒ Array<String>
If specified, Elastic Beanstalk restricts the returned descriptions to include only those that have the specified IDs.
-
#environment_names ⇒ Array<String>
If specified, Elastic Beanstalk restricts the returned descriptions to include only those that have the specified names.
-
#include_deleted ⇒ Boolean
Indicates whether to include deleted environments:.
-
#included_deleted_back_to ⇒ Time
If specified when
IncludeDeletedis set totrue, then environments deleted after this date are displayed. -
#max_records ⇒ Integer
For a paginated request.
-
#next_token ⇒ String
For a paginated request.
-
#version_label ⇒ String
If specified, Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application version.
Instance Attribute Details
#application_name ⇒ String
If specified, Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application.
2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2016 class DescribeEnvironmentsMessage < Struct.new( :application_name, :version_label, :environment_ids, :environment_names, :include_deleted, :included_deleted_back_to, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#environment_ids ⇒ Array<String>
If specified, Elastic Beanstalk restricts the returned descriptions to include only those that have the specified IDs.
2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2016 class DescribeEnvironmentsMessage < Struct.new( :application_name, :version_label, :environment_ids, :environment_names, :include_deleted, :included_deleted_back_to, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#environment_names ⇒ Array<String>
If specified, Elastic Beanstalk restricts the returned descriptions to include only those that have the specified names.
2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2016 class DescribeEnvironmentsMessage < Struct.new( :application_name, :version_label, :environment_ids, :environment_names, :include_deleted, :included_deleted_back_to, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#include_deleted ⇒ Boolean
Indicates whether to include deleted environments:
true: Environments that have been deleted after
IncludedDeletedBackTo are displayed.
false: Do not include deleted environments.
2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2016 class DescribeEnvironmentsMessage < Struct.new( :application_name, :version_label, :environment_ids, :environment_names, :include_deleted, :included_deleted_back_to, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#included_deleted_back_to ⇒ Time
If specified when IncludeDeleted is set to true, then
environments deleted after this date are displayed.
2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2016 class DescribeEnvironmentsMessage < Struct.new( :application_name, :version_label, :environment_ids, :environment_names, :include_deleted, :included_deleted_back_to, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
For a paginated request. Specify a maximum number of environments to include in each response.
If no MaxRecords is specified, all available environments are
retrieved in a single response.
2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2016 class DescribeEnvironmentsMessage < Struct.new( :application_name, :version_label, :environment_ids, :environment_names, :include_deleted, :included_deleted_back_to, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
For a paginated request. Specify a token from a previous response page to retrieve the next response page. All other parameter values must be identical to the ones specified in the initial request.
If no NextToken is specified, the first page is retrieved.
2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2016 class DescribeEnvironmentsMessage < Struct.new( :application_name, :version_label, :environment_ids, :environment_names, :include_deleted, :included_deleted_back_to, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#version_label ⇒ String
If specified, Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application version.
2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2016 class DescribeEnvironmentsMessage < Struct.new( :application_name, :version_label, :environment_ids, :environment_names, :include_deleted, :included_deleted_back_to, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |