Class: Aws::ElasticBeanstalk::Types::DescribeInstancesHealthRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticbeanstalk/types.rb

Overview

Parameters for a call to DescribeInstancesHealth.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_namesArray<String>

Specifies the response elements you wish to receive. To retrieve all attributes, set to All. If no attribute names are specified, returns a list of instances.

Returns:



2133
2134
2135
2136
2137
2138
2139
2140
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2133

class DescribeInstancesHealthRequest < Struct.new(
  :environment_name,
  :environment_id,
  :attribute_names,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#environment_idString

Specify the Elastic Beanstalk environment by ID.

Returns:



2133
2134
2135
2136
2137
2138
2139
2140
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2133

class DescribeInstancesHealthRequest < Struct.new(
  :environment_name,
  :environment_id,
  :attribute_names,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#environment_nameString

Specify the Elastic Beanstalk environment by name.

Returns:



2133
2134
2135
2136
2137
2138
2139
2140
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2133

class DescribeInstancesHealthRequest < Struct.new(
  :environment_name,
  :environment_id,
  :attribute_names,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Specify the pagination token returned by a previous call.

Returns:



2133
2134
2135
2136
2137
2138
2139
2140
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2133

class DescribeInstancesHealthRequest < Struct.new(
  :environment_name,
  :environment_id,
  :attribute_names,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end