Class: Aws::ElasticBeanstalk::Types::DisassociateEnvironmentOperationsRoleMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::DisassociateEnvironmentOperationsRoleMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Request to disassociate the operations role from an environment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#environment_name ⇒ String
The name of the environment from which to disassociate the operations role.
Instance Attribute Details
#environment_name ⇒ String
The name of the environment from which to disassociate the operations role.
2204 2205 2206 2207 2208 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2204 class DisassociateEnvironmentOperationsRoleMessage < Struct.new( :environment_name) SENSITIVE = [] include Aws::Structure end |