Class: Aws::ElasticBeanstalk::Types::EnvironmentResourceDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::EnvironmentResourceDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Describes the Amazon Web Services resources in use by this environment. This data is live.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_groups ⇒ Array<Types::AutoScalingGroup>
The
AutoScalingGroupsused by this environment. -
#cluster ⇒ Types::Cluster
The Amazon EKS cluster that this environment runs on.
-
#environment_name ⇒ String
The name of the environment.
-
#instances ⇒ Array<Types::Instance>
The Amazon EC2 instances used by this environment.
-
#launch_configurations ⇒ Array<Types::LaunchConfiguration>
The Auto Scaling launch configurations in use by this environment.
-
#launch_templates ⇒ Array<Types::LaunchTemplate>
The Amazon EC2 launch templates in use by this environment.
-
#load_balancers ⇒ Array<Types::LoadBalancer>
The LoadBalancers in use by this environment.
-
#queues ⇒ Array<Types::Queue>
The queues used by this environment.
-
#triggers ⇒ Array<Types::Trigger>
The
AutoScalingtriggers in use by this environment.
Instance Attribute Details
#auto_scaling_groups ⇒ Array<Types::AutoScalingGroup>
The AutoScalingGroups used by this environment.
2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2521 class EnvironmentResourceDescription < Struct.new( :environment_name, :auto_scaling_groups, :cluster, :instances, :launch_configurations, :launch_templates, :load_balancers, :triggers, :queues) SENSITIVE = [] include Aws::Structure end |
#cluster ⇒ Types::Cluster
The Amazon EKS cluster that this environment runs on. This member is present only for environments in the Cluster tier.
2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2521 class EnvironmentResourceDescription < Struct.new( :environment_name, :auto_scaling_groups, :cluster, :instances, :launch_configurations, :launch_templates, :load_balancers, :triggers, :queues) SENSITIVE = [] include Aws::Structure end |
#environment_name ⇒ String
The name of the environment.
2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2521 class EnvironmentResourceDescription < Struct.new( :environment_name, :auto_scaling_groups, :cluster, :instances, :launch_configurations, :launch_templates, :load_balancers, :triggers, :queues) SENSITIVE = [] include Aws::Structure end |
#instances ⇒ Array<Types::Instance>
The Amazon EC2 instances used by this environment.
2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2521 class EnvironmentResourceDescription < Struct.new( :environment_name, :auto_scaling_groups, :cluster, :instances, :launch_configurations, :launch_templates, :load_balancers, :triggers, :queues) SENSITIVE = [] include Aws::Structure end |
#launch_configurations ⇒ Array<Types::LaunchConfiguration>
The Auto Scaling launch configurations in use by this environment.
2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2521 class EnvironmentResourceDescription < Struct.new( :environment_name, :auto_scaling_groups, :cluster, :instances, :launch_configurations, :launch_templates, :load_balancers, :triggers, :queues) SENSITIVE = [] include Aws::Structure end |
#launch_templates ⇒ Array<Types::LaunchTemplate>
The Amazon EC2 launch templates in use by this environment.
2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2521 class EnvironmentResourceDescription < Struct.new( :environment_name, :auto_scaling_groups, :cluster, :instances, :launch_configurations, :launch_templates, :load_balancers, :triggers, :queues) SENSITIVE = [] include Aws::Structure end |
#load_balancers ⇒ Array<Types::LoadBalancer>
The LoadBalancers in use by this environment.
2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2521 class EnvironmentResourceDescription < Struct.new( :environment_name, :auto_scaling_groups, :cluster, :instances, :launch_configurations, :launch_templates, :load_balancers, :triggers, :queues) SENSITIVE = [] include Aws::Structure end |
#queues ⇒ Array<Types::Queue>
The queues used by this environment.
2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2521 class EnvironmentResourceDescription < Struct.new( :environment_name, :auto_scaling_groups, :cluster, :instances, :launch_configurations, :launch_templates, :load_balancers, :triggers, :queues) SENSITIVE = [] include Aws::Structure end |
#triggers ⇒ Array<Types::Trigger>
The AutoScaling triggers in use by this environment.
2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2521 class EnvironmentResourceDescription < Struct.new( :environment_name, :auto_scaling_groups, :cluster, :instances, :launch_configurations, :launch_templates, :load_balancers, :triggers, :queues) SENSITIVE = [] include Aws::Structure end |