Class: Aws::ElasticBeanstalk::Types::EnvironmentTier

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticbeanstalk/types.rb

Overview

Describes the properties of an environment tier

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of this environment tier.

Valid values:

  • For Standard-mode EC2-based web serverWebServer

  • For Standard-mode EC2-based backend application with Amazon SQSWorker

  • For Cluster-mode Amazon EKS-based applicationsCluster



2604
2605
2606
2607
2608
2609
2610
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2604

class EnvironmentTier < Struct.new(
  :name,
  :type,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of this environment tier.

Valid values:

  • For Web server tierStandard

  • For Worker tierSQS/HTTP

  • For Cluster tierEKS



2604
2605
2606
2607
2608
2609
2610
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2604

class EnvironmentTier < Struct.new(
  :name,
  :type,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of this environment tier. When you don't set a value to it, Elastic Beanstalk uses the latest compatible worker tier version.

This member is deprecated. Any specific version that you set may become out of date. We recommend leaving it unspecified.



2604
2605
2606
2607
2608
2609
2610
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2604

class EnvironmentTier < Struct.new(
  :name,
  :type,
  :version)
  SENSITIVE = []
  include Aws::Structure
end