Class: Aws::ElasticBeanstalk::Types::EventDescription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticbeanstalk/types.rb

Overview

Describes an event.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_nameString

The application associated with the event.

Returns:

  • (String)


2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2653

class EventDescription < Struct.new(
  :event_date,
  :message,
  :application_name,
  :version_label,
  :template_name,
  :environment_name,
  :platform_arn,
  :request_id,
  :severity)
  SENSITIVE = []
  include Aws::Structure
end

#environment_nameString

The name of the environment associated with this event.

Returns:

  • (String)


2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2653

class EventDescription < Struct.new(
  :event_date,
  :message,
  :application_name,
  :version_label,
  :template_name,
  :environment_name,
  :platform_arn,
  :request_id,
  :severity)
  SENSITIVE = []
  include Aws::Structure
end

#event_dateTime

The date when the event occurred.

Returns:

  • (Time)


2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2653

class EventDescription < Struct.new(
  :event_date,
  :message,
  :application_name,
  :version_label,
  :template_name,
  :environment_name,
  :platform_arn,
  :request_id,
  :severity)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The event message.

Returns:

  • (String)


2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2653

class EventDescription < Struct.new(
  :event_date,
  :message,
  :application_name,
  :version_label,
  :template_name,
  :environment_name,
  :platform_arn,
  :request_id,
  :severity)
  SENSITIVE = []
  include Aws::Structure
end

#platform_arnString

The ARN of the platform version.

Returns:

  • (String)


2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2653

class EventDescription < Struct.new(
  :event_date,
  :message,
  :application_name,
  :version_label,
  :template_name,
  :environment_name,
  :platform_arn,
  :request_id,
  :severity)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The web service request ID for the activity of this event.

Returns:

  • (String)


2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2653

class EventDescription < Struct.new(
  :event_date,
  :message,
  :application_name,
  :version_label,
  :template_name,
  :environment_name,
  :platform_arn,
  :request_id,
  :severity)
  SENSITIVE = []
  include Aws::Structure
end

#severityString

The severity level of this event.

Returns:

  • (String)


2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2653

class EventDescription < Struct.new(
  :event_date,
  :message,
  :application_name,
  :version_label,
  :template_name,
  :environment_name,
  :platform_arn,
  :request_id,
  :severity)
  SENSITIVE = []
  include Aws::Structure
end

#template_nameString

The name of the configuration associated with this event.

Returns:

  • (String)


2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2653

class EventDescription < Struct.new(
  :event_date,
  :message,
  :application_name,
  :version_label,
  :template_name,
  :environment_name,
  :platform_arn,
  :request_id,
  :severity)
  SENSITIVE = []
  include Aws::Structure
end

#version_labelString

The release label for the application version associated with this event.

Returns:

  • (String)


2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2653

class EventDescription < Struct.new(
  :event_date,
  :message,
  :application_name,
  :version_label,
  :template_name,
  :environment_name,
  :platform_arn,
  :request_id,
  :severity)
  SENSITIVE = []
  include Aws::Structure
end