Class: Aws::ElasticBeanstalk::Types::InstanceHealthSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::InstanceHealthSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Represents summary information about the health of an instance. For more information, see Health Colors and Statuses.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#degraded ⇒ Integer
Red. The health agent is reporting a high number of request failures or other issues for an instance or environment.
-
#info ⇒ Integer
Green. An operation is in progress on an instance.
-
#no_data ⇒ Integer
Grey. Elastic Beanstalk and the health agent are reporting no data on an instance.
-
#ok ⇒ Integer
Green. An instance is passing health checks and the health agent is not reporting any problems.
-
#pending ⇒ Integer
Grey. An operation is in progress on an instance within the command timeout.
-
#severe ⇒ Integer
Red. The health agent is reporting a very high number of request failures or other issues for an instance or environment.
-
#unknown ⇒ Integer
Grey. Elastic Beanstalk and the health agent are reporting an insufficient amount of data on an instance.
-
#warning ⇒ Integer
Yellow. The health agent is reporting a moderate number of request failures or other issues for an instance or environment.
Instance Attribute Details
#degraded ⇒ Integer
Red. The health agent is reporting a high number of request failures or other issues for an instance or environment.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2887 class InstanceHealthSummary < Struct.new( :no_data, :unknown, :pending, :ok, :info, :warning, :degraded, :severe) SENSITIVE = [] include Aws::Structure end |
#info ⇒ Integer
Green. An operation is in progress on an instance.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2887 class InstanceHealthSummary < Struct.new( :no_data, :unknown, :pending, :ok, :info, :warning, :degraded, :severe) SENSITIVE = [] include Aws::Structure end |
#no_data ⇒ Integer
Grey. Elastic Beanstalk and the health agent are reporting no data on an instance.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2887 class InstanceHealthSummary < Struct.new( :no_data, :unknown, :pending, :ok, :info, :warning, :degraded, :severe) SENSITIVE = [] include Aws::Structure end |
#ok ⇒ Integer
Green. An instance is passing health checks and the health agent is not reporting any problems.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2887 class InstanceHealthSummary < Struct.new( :no_data, :unknown, :pending, :ok, :info, :warning, :degraded, :severe) SENSITIVE = [] include Aws::Structure end |
#pending ⇒ Integer
Grey. An operation is in progress on an instance within the command timeout.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2887 class InstanceHealthSummary < Struct.new( :no_data, :unknown, :pending, :ok, :info, :warning, :degraded, :severe) SENSITIVE = [] include Aws::Structure end |
#severe ⇒ Integer
Red. The health agent is reporting a very high number of request failures or other issues for an instance or environment.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2887 class InstanceHealthSummary < Struct.new( :no_data, :unknown, :pending, :ok, :info, :warning, :degraded, :severe) SENSITIVE = [] include Aws::Structure end |
#unknown ⇒ Integer
Grey. Elastic Beanstalk and the health agent are reporting an insufficient amount of data on an instance.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2887 class InstanceHealthSummary < Struct.new( :no_data, :unknown, :pending, :ok, :info, :warning, :degraded, :severe) SENSITIVE = [] include Aws::Structure end |
#warning ⇒ Integer
Yellow. The health agent is reporting a moderate number of request failures or other issues for an instance or environment.
2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2887 class InstanceHealthSummary < Struct.new( :no_data, :unknown, :pending, :ok, :info, :warning, :degraded, :severe) SENSITIVE = [] include Aws::Structure end |