Class: Aws::ElasticBeanstalk::Types::MaxAgeRule

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticbeanstalk/types.rb

Overview

A lifecycle rule that deletes application versions after the specified number of days.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#delete_source_from_s3Boolean

Set to true to delete a version's source bundle from Amazon S3 when Elastic Beanstalk deletes the application version.



3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3327

class MaxAgeRule < Struct.new(
  :enabled,
  :max_age_in_days,
  :delete_source_from_s3)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

Specify true to apply the rule, or false to disable it.



3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3327

class MaxAgeRule < Struct.new(
  :enabled,
  :max_age_in_days,
  :delete_source_from_s3)
  SENSITIVE = []
  include Aws::Structure
end

#max_age_in_daysInteger

Specify the number of days to retain an application versions.



3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3327

class MaxAgeRule < Struct.new(
  :enabled,
  :max_age_in_days,
  :delete_source_from_s3)
  SENSITIVE = []
  include Aws::Structure
end