Class: Aws::ElasticBeanstalk::Types::PlatformDescription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticbeanstalk/types.rb

Overview

Detailed information about a platform version.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_ami_listArray<Types::CustomAmi>

The custom AMIs supported by the platform version.

Returns:



3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#date_createdTime

The date when the platform version was created.

Returns:

  • (Time)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#date_updatedTime

The date when the platform version was last updated.

Returns:

  • (Time)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the platform version.

Returns:

  • (String)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#frameworksArray<Types::PlatformFramework>

The frameworks supported by the platform version.

Returns:



3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#maintainerString

Information about the maintainer of the platform version.

Returns:

  • (String)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#operating_system_nameString

The operating system used by the platform version.

Returns:

  • (String)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#operating_system_versionString

The version of the operating system used by the platform version.

Returns:

  • (String)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_arnString

The ARN of the platform version.

Returns:

  • (String)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_branch_lifecycle_stateString

The state of the platform version's branch in its lifecycle.

Possible values: Beta | Supported | Deprecated | Retired

Returns:

  • (String)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_branch_nameString

The platform branch to which the platform version belongs.

Returns:

  • (String)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_categoryString

The category of the platform version.

Returns:

  • (String)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_lifecycle_stateString

The state of the platform version in its lifecycle.

Possible values: Recommended | null

If a null value is returned, the platform version isn't the recommended one for its branch. Each platform branch has a single recommended platform version, typically the most recent one.

Returns:

  • (String)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_nameString

The name of the platform version.

Returns:

  • (String)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_ownerString

The Amazon Web Services account ID of the person who created the platform version.

Returns:

  • (String)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_statusString

The status of the platform version.

Returns:

  • (String)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_versionString

The version of the platform version.

Returns:

  • (String)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#programming_languagesArray<Types::PlatformProgrammingLanguage>

The programming languages supported by the platform version.



3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#solution_stack_nameString

The name of the solution stack used by the platform version.

Returns:

  • (String)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#supported_addon_listArray<String>

The additions supported by the platform version.

Returns:

  • (Array<String>)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#supported_tier_listArray<String>

The tiers supported by the platform version.

Returns:

  • (Array<String>)


3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556

class PlatformDescription < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_name,
  :platform_version,
  :solution_stack_name,
  :platform_status,
  :date_created,
  :date_updated,
  :platform_category,
  :description,
  :maintainer,
  :operating_system_name,
  :operating_system_version,
  :programming_languages,
  :frameworks,
  :custom_ami_list,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end