Class: Aws::ElasticBeanstalk::Types::PlatformSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticbeanstalk/types.rb

Overview

Summary information about a platform version.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#operating_system_nameString

The operating system used by the platform version.



3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3731

class PlatformSummary < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_status,
  :platform_category,
  :operating_system_name,
  :operating_system_version,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_version,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#operating_system_versionString

The version of the operating system used by the platform version.



3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3731

class PlatformSummary < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_status,
  :platform_category,
  :operating_system_name,
  :operating_system_version,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_version,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_arnString

The ARN of the platform version.



3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3731

class PlatformSummary < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_status,
  :platform_category,
  :operating_system_name,
  :operating_system_version,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_version,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_branch_lifecycle_stateString

The state of the platform version's branch in its lifecycle.

Possible values: beta | supported | deprecated | retired



3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3731

class PlatformSummary < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_status,
  :platform_category,
  :operating_system_name,
  :operating_system_version,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_version,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_branch_nameString

The platform branch to which the platform version belongs.



3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3731

class PlatformSummary < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_status,
  :platform_category,
  :operating_system_name,
  :operating_system_version,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_version,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_categoryString

The category of platform version.



3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3731

class PlatformSummary < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_status,
  :platform_category,
  :operating_system_name,
  :operating_system_version,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_version,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_lifecycle_stateString

The state of the platform version in its lifecycle.

Possible values: recommended | empty

If an empty value is returned, the platform version is supported but isn't the recommended one for its branch.



3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3731

class PlatformSummary < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_status,
  :platform_category,
  :operating_system_name,
  :operating_system_version,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_version,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_ownerString

The Amazon Web Services account ID of the person who created the platform version.



3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3731

class PlatformSummary < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_status,
  :platform_category,
  :operating_system_name,
  :operating_system_version,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_version,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_statusString

The status of the platform version. You can create an environment from the platform version once it is ready.



3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3731

class PlatformSummary < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_status,
  :platform_category,
  :operating_system_name,
  :operating_system_version,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_version,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#platform_versionString

The version string of the platform version.



3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3731

class PlatformSummary < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_status,
  :platform_category,
  :operating_system_name,
  :operating_system_version,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_version,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#supported_addon_listArray<String>

The additions associated with the platform version.



3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3731

class PlatformSummary < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_status,
  :platform_category,
  :operating_system_name,
  :operating_system_version,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_version,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end

#supported_tier_listArray<String>

The tiers in which the platform version runs.



3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
3744
3745
3746
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3731

class PlatformSummary < Struct.new(
  :platform_arn,
  :platform_owner,
  :platform_status,
  :platform_category,
  :operating_system_name,
  :operating_system_version,
  :supported_tier_list,
  :supported_addon_list,
  :platform_lifecycle_state,
  :platform_version,
  :platform_branch_name,
  :platform_branch_lifecycle_state)
  SENSITIVE = []
  include Aws::Structure
end