Class: Aws::ElasticBeanstalk::Types::RestartAppServerMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::RestartAppServerMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#environment_id ⇒ String
The ID of the environment to restart the server for.
-
#environment_name ⇒ String
The name of the environment to restart the server for.
Instance Attribute Details
#environment_id ⇒ String
The ID of the environment to restart the server for.
Condition: You must specify either this or an EnvironmentName, or
both. If you do not specify either, Elastic Beanstalk returns
MissingRequiredParameter error.
3943 3944 3945 3946 3947 3948 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3943 class RestartAppServerMessage < Struct.new( :environment_id, :environment_name) SENSITIVE = [] include Aws::Structure end |
#environment_name ⇒ String
The name of the environment to restart the server for.
Condition: You must specify either this or an EnvironmentId, or
both. If you do not specify either, Elastic Beanstalk returns
MissingRequiredParameter error.
3943 3944 3945 3946 3947 3948 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3943 class RestartAppServerMessage < Struct.new( :environment_id, :environment_name) SENSITIVE = [] include Aws::Structure end |