Class: Aws::ElasticBeanstalk::Types::RetrieveEnvironmentInfoMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::RetrieveEnvironmentInfoMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Request to download logs retrieved with RequestEnvironmentInfo.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#environment_id ⇒ String
The ID of the data's environment.
-
#environment_name ⇒ String
The name of the data's environment.
-
#info_type ⇒ String
The type of information to retrieve.
Instance Attribute Details
#environment_id ⇒ String
The ID of the data's environment.
If no such environment is found, returns an InvalidParameterValue
error.
Condition: You must specify either this or an EnvironmentName, or
both. If you do not specify either, Elastic Beanstalk returns
MissingRequiredParameter error.
3980 3981 3982 3983 3984 3985 3986 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3980 class RetrieveEnvironmentInfoMessage < Struct.new( :environment_id, :environment_name, :info_type) SENSITIVE = [] include Aws::Structure end |
#environment_name ⇒ String
The name of the data's environment.
If no such environment is found, returns an InvalidParameterValue
error.
Condition: You must specify either this or an EnvironmentId, or
both. If you do not specify either, Elastic Beanstalk returns
MissingRequiredParameter error.
3980 3981 3982 3983 3984 3985 3986 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3980 class RetrieveEnvironmentInfoMessage < Struct.new( :environment_id, :environment_name, :info_type) SENSITIVE = [] include Aws::Structure end |
#info_type ⇒ String
The type of information to retrieve.
3980 3981 3982 3983 3984 3985 3986 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3980 class RetrieveEnvironmentInfoMessage < Struct.new( :environment_id, :environment_name, :info_type) SENSITIVE = [] include Aws::Structure end |