Class: Aws::ElasticBeanstalk::Types::SingleInstanceHealth
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::SingleInstanceHealth
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Detailed health information about an Amazon EC2 instance in your Elastic Beanstalk environment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_metrics ⇒ Types::ApplicationMetrics
Request metrics from your application.
-
#availability_zone ⇒ String
The availability zone in which the instance runs.
-
#causes ⇒ Array<String>
Represents the causes, which provide more information about the current health status.
-
#color ⇒ String
Represents the color indicator that gives you information about the health of the EC2 instance.
-
#deployment ⇒ Types::Deployment
Information about the most recent deployment to an instance.
-
#health_status ⇒ String
Returns the health status of the specified instance.
-
#instance_id ⇒ String
The ID of the Amazon EC2 instance.
-
#instance_type ⇒ String
The instance's type.
-
#launched_at ⇒ Time
The time at which the EC2 instance was launched.
-
#system ⇒ Types::SystemStatus
Operating system metrics from the instance.
Instance Attribute Details
#application_metrics ⇒ Types::ApplicationMetrics
Request metrics from your application.
4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 4149 4150 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4137 class SingleInstanceHealth < Struct.new( :instance_id, :health_status, :color, :causes, :launched_at, :application_metrics, :system, :deployment, :availability_zone, :instance_type) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The availability zone in which the instance runs.
4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 4149 4150 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4137 class SingleInstanceHealth < Struct.new( :instance_id, :health_status, :color, :causes, :launched_at, :application_metrics, :system, :deployment, :availability_zone, :instance_type) SENSITIVE = [] include Aws::Structure end |
#causes ⇒ Array<String>
Represents the causes, which provide more information about the current health status.
4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 4149 4150 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4137 class SingleInstanceHealth < Struct.new( :instance_id, :health_status, :color, :causes, :launched_at, :application_metrics, :system, :deployment, :availability_zone, :instance_type) SENSITIVE = [] include Aws::Structure end |
#color ⇒ String
Represents the color indicator that gives you information about the health of the EC2 instance. For more information, see Health Colors and Statuses.
4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 4149 4150 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4137 class SingleInstanceHealth < Struct.new( :instance_id, :health_status, :color, :causes, :launched_at, :application_metrics, :system, :deployment, :availability_zone, :instance_type) SENSITIVE = [] include Aws::Structure end |
#deployment ⇒ Types::Deployment
Information about the most recent deployment to an instance.
4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 4149 4150 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4137 class SingleInstanceHealth < Struct.new( :instance_id, :health_status, :color, :causes, :launched_at, :application_metrics, :system, :deployment, :availability_zone, :instance_type) SENSITIVE = [] include Aws::Structure end |
#health_status ⇒ String
Returns the health status of the specified instance. For more information, see Health Colors and Statuses.
4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 4149 4150 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4137 class SingleInstanceHealth < Struct.new( :instance_id, :health_status, :color, :causes, :launched_at, :application_metrics, :system, :deployment, :availability_zone, :instance_type) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The ID of the Amazon EC2 instance.
4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 4149 4150 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4137 class SingleInstanceHealth < Struct.new( :instance_id, :health_status, :color, :causes, :launched_at, :application_metrics, :system, :deployment, :availability_zone, :instance_type) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance's type.
4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 4149 4150 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4137 class SingleInstanceHealth < Struct.new( :instance_id, :health_status, :color, :causes, :launched_at, :application_metrics, :system, :deployment, :availability_zone, :instance_type) SENSITIVE = [] include Aws::Structure end |
#launched_at ⇒ Time
The time at which the EC2 instance was launched.
4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 4149 4150 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4137 class SingleInstanceHealth < Struct.new( :instance_id, :health_status, :color, :causes, :launched_at, :application_metrics, :system, :deployment, :availability_zone, :instance_type) SENSITIVE = [] include Aws::Structure end |
#system ⇒ Types::SystemStatus
Operating system metrics from the instance.
4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 4149 4150 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4137 class SingleInstanceHealth < Struct.new( :instance_id, :health_status, :color, :causes, :launched_at, :application_metrics, :system, :deployment, :availability_zone, :instance_type) SENSITIVE = [] include Aws::Structure end |