Class: Aws::ElasticBeanstalk::Types::TerminateEnvironmentMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticbeanstalk/types.rb

Overview

Request to terminate an environment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#environment_idString

The ID of the environment to terminate.

Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, Elastic Beanstalk returns MissingRequiredParameter error.

Returns:



4417
4418
4419
4420
4421
4422
4423
4424
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4417

class TerminateEnvironmentMessage < Struct.new(
  :environment_id,
  :environment_name,
  :terminate_resources,
  :force_terminate)
  SENSITIVE = []
  include Aws::Structure
end

#environment_nameString

The name of the environment to terminate.

Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, Elastic Beanstalk returns MissingRequiredParameter error.

Returns:



4417
4418
4419
4420
4421
4422
4423
4424
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4417

class TerminateEnvironmentMessage < Struct.new(
  :environment_id,
  :environment_name,
  :terminate_resources,
  :force_terminate)
  SENSITIVE = []
  include Aws::Structure
end

#force_terminateBoolean

Terminates the target environment even if another environment in the same group is dependent on it.

Returns:



4417
4418
4419
4420
4421
4422
4423
4424
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4417

class TerminateEnvironmentMessage < Struct.new(
  :environment_id,
  :environment_name,
  :terminate_resources,
  :force_terminate)
  SENSITIVE = []
  include Aws::Structure
end

#terminate_resourcesBoolean

Indicates whether the associated Amazon Web Services resources should shut down when the environment is terminated:

  • true: The specified environment as well as the associated Amazon Web Services resources, such as Auto Scaling group and LoadBalancer, are terminated.

  • false: Elastic Beanstalk resource management is removed from the environment, but the Amazon Web Services resources continue to operate.

For more information, see the Elastic Beanstalk User Guide.

Default: true

Valid Values: true | false

Returns:



4417
4418
4419
4420
4421
4422
4423
4424
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4417

class TerminateEnvironmentMessage < Struct.new(
  :environment_id,
  :environment_name,
  :terminate_resources,
  :force_terminate)
  SENSITIVE = []
  include Aws::Structure
end