Class: Aws::ElasticBeanstalk::Types::UpdateApplicationVersionMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticbeanstalk/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_nameString

The name of the application associated with this version.

If no application is found with this name, UpdateApplication returns an InvalidParameterValue error.



4549
4550
4551
4552
4553
4554
4555
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4549

class UpdateApplicationVersionMessage < Struct.new(
  :application_name,
  :version_label,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A new description for this version.



4549
4550
4551
4552
4553
4554
4555
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4549

class UpdateApplicationVersionMessage < Struct.new(
  :application_name,
  :version_label,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#version_labelString

The name of the version to update.

If no application version is found with this label, UpdateApplication returns an InvalidParameterValue error.



4549
4550
4551
4552
4553
4554
4555
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 4549

class UpdateApplicationVersionMessage < Struct.new(
  :application_name,
  :version_label,
  :description)
  SENSITIVE = []
  include Aws::Structure
end