Class: Aws::ElasticBeanstalk::Waiters::EnvironmentUpdated

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-elasticbeanstalk/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ EnvironmentUpdated

Returns a new instance of EnvironmentUpdated.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 20
  • :delay (Integer) — default: 20
  • :before_attempt (Proc)
  • :before_wait (Proc)


174
175
# File 'lib/aws-sdk-elasticbeanstalk/waiters.rb', line 174

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



206
207
208
# File 'lib/aws-sdk-elasticbeanstalk/waiters.rb', line 206

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::EnvironmentDescriptionsMessage

Returns a response object which responds to the following methods:

Options Hash (params):

  • :application_name (String)

    If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application.

  • :version_label (String)

    If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application version.

  • :environment_ids (Array<String>)

    If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that have the specified IDs.

  • :environment_names (Array<String>)

    If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that have the specified names.

  • :include_deleted (Boolean)

    Indicates whether to include deleted environments:

    true: Environments that have been deleted after IncludedDeletedBackTo are displayed.

    false: Do not include deleted environments.

  • :included_deleted_back_to (Time, DateTime, Date, Integer, String)

    If specified when IncludeDeleted is set to true, then environments deleted after this date are displayed.

  • :max_records (Integer)

    For a paginated request. Specify a maximum number of environments to include in each response.

    If no MaxRecords is specified, all available environments are retrieved in a single response.

  • :next_token (String)

    For a paginated request. Specify a token from a previous response page to retrieve the next response page. All other parameter values must be identical to the ones specified in the initial request.

    If no NextToken is specified, the first page is retrieved.

Returns:



201
# File 'lib/aws-sdk-elasticbeanstalk/waiters.rb', line 201

def wait: (