Class: Aws::ElasticBeanstalk::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ElasticBeanstalk::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-elasticbeanstalk/client.rb
Overview
An API client for ElasticBeanstalk. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ElasticBeanstalk::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#abort_environment_update(params = {}) ⇒ Struct
Cancels in-progress environment configuration update or application version deployment.
-
#apply_environment_managed_action(params = {}) ⇒ Types::ApplyEnvironmentManagedActionResult
Applies a scheduled managed action immediately.
-
#associate_environment_operations_role(params = {}) ⇒ Struct
Add or change the operations role used by an environment.
-
#check_dns_availability(params = {}) ⇒ Types::CheckDNSAvailabilityResultMessage
Checks if the specified CNAME is available.
-
#compose_environments(params = {}) ⇒ Types::EnvironmentDescriptionsMessage
Create or update a group of environments that each run a separate component of a single application.
-
#create_application(params = {}) ⇒ Types::ApplicationDescriptionMessage
Creates an application that has one configuration template named ‘default` and no application versions.
-
#create_application_version(params = {}) ⇒ Types::ApplicationVersionDescriptionMessage
Creates an application version for the specified application.
-
#create_configuration_template(params = {}) ⇒ Types::ConfigurationSettingsDescription
Creates an AWS Elastic Beanstalk configuration template, associated with a specific Elastic Beanstalk application.
-
#create_environment(params = {}) ⇒ Types::EnvironmentDescription
Launches an AWS Elastic Beanstalk environment for the specified application using the specified configuration.
-
#create_platform_version(params = {}) ⇒ Types::CreatePlatformVersionResult
Create a new version of your custom platform.
-
#create_storage_location(params = {}) ⇒ Types::CreateStorageLocationResultMessage
Creates a bucket in Amazon S3 to store application versions, logs, and other files used by Elastic Beanstalk environments.
-
#delete_application(params = {}) ⇒ Struct
Deletes the specified application along with all associated versions and configurations.
-
#delete_application_version(params = {}) ⇒ Struct
Deletes the specified version from the specified application.
-
#delete_configuration_template(params = {}) ⇒ Struct
Deletes the specified configuration template.
-
#delete_environment_configuration(params = {}) ⇒ Struct
Deletes the draft configuration associated with the running environment.
-
#delete_platform_version(params = {}) ⇒ Types::DeletePlatformVersionResult
Deletes the specified version of a custom platform.
-
#describe_account_attributes(params = {}) ⇒ Types::DescribeAccountAttributesResult
Returns attributes related to AWS Elastic Beanstalk that are associated with the calling AWS account.
-
#describe_application_versions(params = {}) ⇒ Types::ApplicationVersionDescriptionsMessage
Retrieve a list of application versions.
-
#describe_applications(params = {}) ⇒ Types::ApplicationDescriptionsMessage
Returns the descriptions of existing applications.
-
#describe_configuration_options(params = {}) ⇒ Types::ConfigurationOptionsDescription
Describes the configuration options that are used in a particular configuration template or environment, or that a specified solution stack defines.
-
#describe_configuration_settings(params = {}) ⇒ Types::ConfigurationSettingsDescriptions
Returns a description of the settings for the specified configuration set, that is, either a configuration template or the configuration set associated with a running environment.
-
#describe_environment_health(params = {}) ⇒ Types::DescribeEnvironmentHealthResult
Returns information about the overall health of the specified environment.
-
#describe_environment_managed_action_history(params = {}) ⇒ Types::DescribeEnvironmentManagedActionHistoryResult
Lists an environment’s completed and failed managed actions.
-
#describe_environment_managed_actions(params = {}) ⇒ Types::DescribeEnvironmentManagedActionsResult
Lists an environment’s upcoming and in-progress managed actions.
-
#describe_environment_resources(params = {}) ⇒ Types::EnvironmentResourceDescriptionsMessage
Returns AWS resources for this environment.
-
#describe_environments(params = {}) ⇒ Types::EnvironmentDescriptionsMessage
Returns descriptions for existing environments.
-
#describe_events(params = {}) ⇒ Types::EventDescriptionsMessage
Returns list of event descriptions matching criteria up to the last 6 weeks.
-
#describe_instances_health(params = {}) ⇒ Types::DescribeInstancesHealthResult
Retrieves detailed information about the health of instances in your AWS Elastic Beanstalk.
-
#describe_platform_version(params = {}) ⇒ Types::DescribePlatformVersionResult
Describes a platform version.
-
#disassociate_environment_operations_role(params = {}) ⇒ Struct
Disassociate the operations role from an environment.
-
#list_available_solution_stacks(params = {}) ⇒ Types::ListAvailableSolutionStacksResultMessage
Returns a list of the available solution stack names, with the public version first and then in reverse chronological order.
-
#list_platform_branches(params = {}) ⇒ Types::ListPlatformBranchesResult
Lists the platform branches available for your account in an AWS Region.
-
#list_platform_versions(params = {}) ⇒ Types::ListPlatformVersionsResult
Lists the platform versions available for your account in an AWS Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ResourceTagsDescriptionMessage
Return the tags applied to an AWS Elastic Beanstalk resource.
-
#rebuild_environment(params = {}) ⇒ Struct
Deletes and recreates all of the AWS resources (for example: the Auto Scaling group, load balancer, etc.) for a specified environment and forces a restart.
-
#request_environment_info(params = {}) ⇒ Struct
Initiates a request to compile the specified type of information of the deployed environment.
-
#restart_app_server(params = {}) ⇒ Struct
Causes the environment to restart the application container server running on each Amazon EC2 instance.
-
#retrieve_environment_info(params = {}) ⇒ Types::RetrieveEnvironmentInfoResultMessage
Retrieves the compiled information from a RequestEnvironmentInfo request.
-
#swap_environment_cnames(params = {}) ⇒ Struct
Swaps the CNAMEs of two environments.
-
#terminate_environment(params = {}) ⇒ Types::EnvironmentDescription
Terminates the specified environment.
-
#update_application(params = {}) ⇒ Types::ApplicationDescriptionMessage
Updates the specified application to have the specified properties.
-
#update_application_resource_lifecycle(params = {}) ⇒ Types::ApplicationResourceLifecycleDescriptionMessage
Modifies lifecycle settings for an application.
-
#update_application_version(params = {}) ⇒ Types::ApplicationVersionDescriptionMessage
Updates the specified application version to have the specified properties.
-
#update_configuration_template(params = {}) ⇒ Types::ConfigurationSettingsDescription
Updates the specified configuration template to have the specified properties or configuration option values.
-
#update_environment(params = {}) ⇒ Types::EnvironmentDescription
Updates the environment description, deploys a new application version, updates the configuration settings to an entirely new configuration template, or updates select configuration option values in the running environment.
-
#update_tags_for_resource(params = {}) ⇒ Struct
Update the list of tags applied to an AWS Elastic Beanstalk resource.
-
#validate_configuration_settings(params = {}) ⇒ Types::ConfigurationSettingsValidationMessages
Takes a set of configuration settings and either a configuration template or environment, and determines whether those values are valid.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4788 4789 4790 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 4788 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4791 4792 4793 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 4791 def errors_module Errors end |
Instance Method Details
#abort_environment_update(params = {}) ⇒ Struct
Cancels in-progress environment configuration update or application version deployment.
510 511 512 513 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 510 def abort_environment_update(params = {}, = {}) req = build_request(:abort_environment_update, params) req.send_request() end |
#apply_environment_managed_action(params = {}) ⇒ Types::ApplyEnvironmentManagedActionResult
Applies a scheduled managed action immediately. A managed action can be applied only if its status is ‘Scheduled`. Get the status and action ID of a managed action with DescribeEnvironmentManagedActions.
554 555 556 557 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 554 def apply_environment_managed_action(params = {}, = {}) req = build_request(:apply_environment_managed_action, params) req.send_request() end |
#associate_environment_operations_role(params = {}) ⇒ Struct
Add or change the operations role used by an environment. After this call is made, Elastic Beanstalk uses the associated operations role for permissions to downstream services during subsequent calls acting on this environment. For more information, see [Operations roles] in the *AWS Elastic Beanstalk Developer Guide*.
[1]: docs.aws.amazon.com/elasticbeanstalk/latest/dg/iam-operationsrole.html
589 590 591 592 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 589 def associate_environment_operations_role(params = {}, = {}) req = build_request(:associate_environment_operations_role, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4644 4645 4646 4647 4648 4649 4650 4651 4652 4653 4654 4655 4656 4657 4658 4659 4660 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 4644 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ElasticBeanstalk') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-elasticbeanstalk' context[:gem_version] = '1.104.0' Seahorse::Client::Request.new(handlers, context) end |
#check_dns_availability(params = {}) ⇒ Types::CheckDNSAvailabilityResultMessage
Checks if the specified CNAME is available.
634 635 636 637 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 634 def check_dns_availability(params = {}, = {}) req = build_request(:check_dns_availability, params) req.send_request() end |
#compose_environments(params = {}) ⇒ Types::EnvironmentDescriptionsMessage
Create or update a group of environments that each run a separate component of a single application. Takes a list of version labels that specify application source bundles for each of the environments to create or update. The name of each environment and other required information must be included in the source bundles in an environment manifest named ‘env.yaml`. See [Compose Environments] for details.
[1]: docs.aws.amazon.com/elasticbeanstalk/latest/dg/environment-mgmt-compose.html
722 723 724 725 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 722 def compose_environments(params = {}, = {}) req = build_request(:compose_environments, params) req.send_request() end |
#create_application(params = {}) ⇒ Types::ApplicationDescriptionMessage
Creates an application that has one configuration template named ‘default` and no application versions.
824 825 826 827 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 824 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_application_version(params = {}) ⇒ Types::ApplicationVersionDescriptionMessage
Creates an application version for the specified application. You can create an application version from a source bundle in Amazon S3, a commit in AWS CodeCommit, or the output of an AWS CodeBuild build as follows:
Specify a commit in an AWS CodeCommit repository with ‘SourceBuildInformation`.
Specify a build in an AWS CodeBuild with ‘SourceBuildInformation` and `BuildConfiguration`.
Specify a source bundle in S3 with ‘SourceBundle`
Omit both ‘SourceBuildInformation` and `SourceBundle` to use the default sample application.
<note markdown=“1”> After you create an application version with a specified Amazon S3 bucket and key location, you can’t change that Amazon S3 location. If you change the Amazon S3 location, you receive an exception when you attempt to launch an environment from the application version.
</note>
1001 1002 1003 1004 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 1001 def create_application_version(params = {}, = {}) req = build_request(:create_application_version, params) req.send_request() end |
#create_configuration_template(params = {}) ⇒ Types::ConfigurationSettingsDescription
Creates an AWS Elastic Beanstalk configuration template, associated with a specific Elastic Beanstalk application. You define application configuration settings in a configuration template. You can then use the configuration template to deploy different versions of the application with the same configuration settings.
Templates aren’t associated with any environment. The ‘EnvironmentName` response element is always `null`.
Related Topics
-
DescribeConfigurationOptions
-
DescribeConfigurationSettings
-
ListAvailableSolutionStacks
1186 1187 1188 1189 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 1186 def create_configuration_template(params = {}, = {}) req = build_request(:create_configuration_template, params) req.send_request() end |
#create_environment(params = {}) ⇒ Types::EnvironmentDescription
Launches an AWS Elastic Beanstalk environment for the specified application using the specified configuration.
1440 1441 1442 1443 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 1440 def create_environment(params = {}, = {}) req = build_request(:create_environment, params) req.send_request() end |
#create_platform_version(params = {}) ⇒ Types::CreatePlatformVersionResult
Create a new version of your custom platform.
1522 1523 1524 1525 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 1522 def create_platform_version(params = {}, = {}) req = build_request(:create_platform_version, params) req.send_request() end |
#create_storage_location(params = {}) ⇒ Types::CreateStorageLocationResultMessage
Creates a bucket in Amazon S3 to store application versions, logs, and other files used by Elastic Beanstalk environments. The Elastic Beanstalk console and EB CLI call this API the first time you create an environment in a region. If the storage location already exists, ‘CreateStorageLocation` still returns the bucket name but does not create a new bucket.
1559 1560 1561 1562 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 1559 def create_storage_location(params = {}, = {}) req = build_request(:create_storage_location, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes the specified application along with all associated versions and configurations. The application versions will not be deleted from your Amazon S3 bucket.
<note markdown=“1”> You cannot delete an application that has a running environment.
</note>
1601 1602 1603 1604 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 1601 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_application_version(params = {}) ⇒ Struct
Deletes the specified version from the specified application.
<note markdown=“1”> You cannot delete an application version that is associated with a running environment.
</note>
1649 1650 1651 1652 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 1649 def delete_application_version(params = {}, = {}) req = build_request(:delete_application_version, params) req.send_request() end |
#delete_configuration_template(params = {}) ⇒ Struct
Deletes the specified configuration template.
<note markdown=“1”> When you launch an environment using a configuration template, the environment gets a copy of the template. You can delete or modify the environment’s copy of the template without affecting the running environment.
</note>
1692 1693 1694 1695 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 1692 def delete_configuration_template(params = {}, = {}) req = build_request(:delete_configuration_template, params) req.send_request() end |
#delete_environment_configuration(params = {}) ⇒ Struct
Deletes the draft configuration associated with the running environment.
Updating a running environment with any configuration changes creates a draft configuration set. You can get the draft configuration using DescribeConfigurationSettings while the update is in progress or if the update fails. The ‘DeploymentStatus` for the draft configuration indicates whether the deployment is in process or has failed. The draft configuration remains in existence until it is deleted with this action.
1737 1738 1739 1740 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 1737 def delete_environment_configuration(params = {}, = {}) req = build_request(:delete_environment_configuration, params) req.send_request() end |
#delete_platform_version(params = {}) ⇒ Types::DeletePlatformVersionResult
Deletes the specified version of a custom platform.
1778 1779 1780 1781 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 1778 def delete_platform_version(params = {}, = {}) req = build_request(:delete_platform_version, params) req.send_request() end |
#describe_account_attributes(params = {}) ⇒ Types::DescribeAccountAttributesResult
Returns attributes related to AWS Elastic Beanstalk that are associated with the calling AWS account.
The result currently has one set of attributes—resource quotas.
1804 1805 1806 1807 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 1804 def describe_account_attributes(params = {}, = {}) req = build_request(:describe_account_attributes, params) req.send_request() end |
#describe_application_versions(params = {}) ⇒ Types::ApplicationVersionDescriptionsMessage
Retrieve a list of application versions.
1908 1909 1910 1911 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 1908 def describe_application_versions(params = {}, = {}) req = build_request(:describe_application_versions, params) req.send_request() end |
#describe_applications(params = {}) ⇒ Types::ApplicationDescriptionsMessage
Returns the descriptions of existing applications.
1999 2000 2001 2002 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 1999 def describe_applications(params = {}, = {}) req = build_request(:describe_applications, params) req.send_request() end |
#describe_configuration_options(params = {}) ⇒ Types::ConfigurationOptionsDescription
Describes the configuration options that are used in a particular configuration template or environment, or that a specified solution stack defines. The description includes the values the options, their default values, and an indication of the required action on a running environment if an option value is changed.
2116 2117 2118 2119 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 2116 def (params = {}, = {}) req = build_request(:describe_configuration_options, params) req.send_request() end |
#describe_configuration_settings(params = {}) ⇒ Types::ConfigurationSettingsDescriptions
Returns a description of the settings for the specified configuration set, that is, either a configuration template or the configuration set associated with a running environment.
When describing the settings for the configuration set associated with a running environment, it is possible to receive two sets of setting descriptions. One is the deployed configuration set, and the other is a draft configuration of an environment that is either in the process of deployment or that failed to deploy.
Related Topics
-
DeleteEnvironmentConfiguration
^
2242 2243 2244 2245 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 2242 def describe_configuration_settings(params = {}, = {}) req = build_request(:describe_configuration_settings, params) req.send_request() end |
#describe_environment_health(params = {}) ⇒ Types::DescribeEnvironmentHealthResult
Returns information about the overall health of the specified environment. The DescribeEnvironmentHealth operation is only available with AWS Elastic Beanstalk Enhanced Health.
2373 2374 2375 2376 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 2373 def describe_environment_health(params = {}, = {}) req = build_request(:describe_environment_health, params) req.send_request() end |
#describe_environment_managed_action_history(params = {}) ⇒ Types::DescribeEnvironmentManagedActionHistoryResult
Lists an environment’s completed and failed managed actions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2425 2426 2427 2428 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 2425 def describe_environment_managed_action_history(params = {}, = {}) req = build_request(:describe_environment_managed_action_history, params) req.send_request() end |
#describe_environment_managed_actions(params = {}) ⇒ Types::DescribeEnvironmentManagedActionsResult
Lists an environment’s upcoming and in-progress managed actions.
2466 2467 2468 2469 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 2466 def describe_environment_managed_actions(params = {}, = {}) req = build_request(:describe_environment_managed_actions, params) req.send_request() end |
#describe_environment_resources(params = {}) ⇒ Types::EnvironmentResourceDescriptionsMessage
Returns AWS resources for this environment.
2561 2562 2563 2564 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 2561 def describe_environment_resources(params = {}, = {}) req = build_request(:describe_environment_resources, params) req.send_request() end |
#describe_environments(params = {}) ⇒ Types::EnvironmentDescriptionsMessage
Returns descriptions for existing environments.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* environment_exists
* environment_terminated
* environment_updated
2711 2712 2713 2714 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 2711 def describe_environments(params = {}, = {}) req = build_request(:describe_environments, params) req.send_request() end |
#describe_events(params = {}) ⇒ Types::EventDescriptionsMessage
Returns list of event descriptions matching criteria up to the last 6 weeks.
<note markdown=“1”> This action returns the most recent 1,000 events from the specified ‘NextToken`.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2863 2864 2865 2866 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 2863 def describe_events(params = {}, = {}) req = build_request(:describe_events, params) req.send_request() end |
#describe_instances_health(params = {}) ⇒ Types::DescribeInstancesHealthResult
Retrieves detailed information about the health of instances in your AWS Elastic Beanstalk. This operation requires [enhanced health reporting].
[1]: docs.aws.amazon.com/elasticbeanstalk/latest/dg/health-enhanced.html
3014 3015 3016 3017 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 3014 def describe_instances_health(params = {}, = {}) req = build_request(:describe_instances_health, params) req.send_request() end |
#describe_platform_version(params = {}) ⇒ Types::DescribePlatformVersionResult
Describes a platform version. Provides full details. Compare to ListPlatformVersions, which provides summary information about a list of platform versions.
For definitions of platform version and other platform-related terms, see [AWS Elastic Beanstalk Platforms Glossary].
[1]: docs.aws.amazon.com/elasticbeanstalk/latest/dg/platforms-glossary.html
3079 3080 3081 3082 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 3079 def describe_platform_version(params = {}, = {}) req = build_request(:describe_platform_version, params) req.send_request() end |
#disassociate_environment_operations_role(params = {}) ⇒ Struct
Disassociate the operations role from an environment. After this call is made, Elastic Beanstalk uses the caller’s permissions for permissions to downstream services during subsequent calls acting on this environment. For more information, see [Operations roles] in the *AWS Elastic Beanstalk Developer Guide*.
[1]: docs.aws.amazon.com/elasticbeanstalk/latest/dg/iam-operationsrole.html
3110 3111 3112 3113 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 3110 def disassociate_environment_operations_role(params = {}, = {}) req = build_request(:disassociate_environment_operations_role, params) req.send_request() end |
#list_available_solution_stacks(params = {}) ⇒ Types::ListAvailableSolutionStacksResultMessage
Returns a list of the available solution stack names, with the public version first and then in reverse chronological order.
3187 3188 3189 3190 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 3187 def list_available_solution_stacks(params = {}, = {}) req = build_request(:list_available_solution_stacks, params) req.send_request() end |
#list_platform_branches(params = {}) ⇒ Types::ListPlatformBranchesResult
Lists the platform branches available for your account in an AWS Region. Provides summary information about each platform branch.
For definitions of platform branch and other platform-related terms, see [AWS Elastic Beanstalk Platforms Glossary].
[1]: docs.aws.amazon.com/elasticbeanstalk/latest/dg/platforms-glossary.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3285 3286 3287 3288 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 3285 def list_platform_branches(params = {}, = {}) req = build_request(:list_platform_branches, params) req.send_request() end |
#list_platform_versions(params = {}) ⇒ Types::ListPlatformVersionsResult
Lists the platform versions available for your account in an AWS Region. Provides summary information about each platform version. Compare to DescribePlatformVersion, which provides full details about a single platform version.
For definitions of platform version and other platform-related terms, see [AWS Elastic Beanstalk Platforms Glossary].
[1]: docs.aws.amazon.com/elasticbeanstalk/latest/dg/platforms-glossary.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3361 3362 3363 3364 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 3361 def list_platform_versions(params = {}, = {}) req = build_request(:list_platform_versions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ResourceTagsDescriptionMessage
Return the tags applied to an AWS Elastic Beanstalk resource. The response contains a list of tag key-value pairs.
Elastic Beanstalk supports tagging of all of its resources. For details about resource tagging, see [Tagging Application Resources].
[1]: docs.aws.amazon.com/elasticbeanstalk/latest/dg/applications-tagging-resources.html
3405 3406 3407 3408 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 3405 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#rebuild_environment(params = {}) ⇒ Struct
Deletes and recreates all of the AWS resources (for example: the Auto Scaling group, load balancer, etc.) for a specified environment and forces a restart.
3450 3451 3452 3453 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 3450 def rebuild_environment(params = {}, = {}) req = build_request(:rebuild_environment, params) req.send_request() end |
#request_environment_info(params = {}) ⇒ Struct
Initiates a request to compile the specified type of information of the deployed environment.
Setting the ‘InfoType` to `tail` compiles the last lines from the application server log files of every Amazon EC2 instance in your environment.
Setting the ‘InfoType` to `bundle` compresses the application server log files for every Amazon EC2 instance into a `.zip` file. Legacy and .NET containers do not support bundle logs.
Setting the ‘InfoType` to `analyze` collects recent events, instance health, and logs from your environment and sends them to Amazon Bedrock in your account to generate diagnostic insights and recommended next steps.
Use RetrieveEnvironmentInfo to obtain the set of logs.
Related Topics
-
RetrieveEnvironmentInfo
^
3526 3527 3528 3529 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 3526 def request_environment_info(params = {}, = {}) req = build_request(:request_environment_info, params) req.send_request() end |
#restart_app_server(params = {}) ⇒ Struct
Causes the environment to restart the application container server running on each Amazon EC2 instance.
3570 3571 3572 3573 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 3570 def restart_app_server(params = {}, = {}) req = build_request(:restart_app_server, params) req.send_request() end |
#retrieve_environment_info(params = {}) ⇒ Types::RetrieveEnvironmentInfoResultMessage
Retrieves the compiled information from a RequestEnvironmentInfo request.
Related Topics
-
RequestEnvironmentInfo
^
3653 3654 3655 3656 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 3653 def retrieve_environment_info(params = {}, = {}) req = build_request(:retrieve_environment_info, params) req.send_request() end |
#swap_environment_cnames(params = {}) ⇒ Struct
Swaps the CNAMEs of two environments.
3716 3717 3718 3719 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 3716 def swap_environment_cnames(params = {}, = {}) req = build_request(:swap_environment_cnames, params) req.send_request() end |
#terminate_environment(params = {}) ⇒ Types::EnvironmentDescription
Terminates the specified environment.
3860 3861 3862 3863 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 3860 def terminate_environment(params = {}, = {}) req = build_request(:terminate_environment, params) req.send_request() end |
#update_application(params = {}) ⇒ Types::ApplicationDescriptionMessage
Updates the specified application to have the specified properties.
<note markdown=“1”> If a property (for example, ‘description`) is not provided, the value remains unchanged. To clear these properties, specify an empty string.
</note>
3945 3946 3947 3948 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 3945 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_application_resource_lifecycle(params = {}) ⇒ Types::ApplicationResourceLifecycleDescriptionMessage
Modifies lifecycle settings for an application.
3999 4000 4001 4002 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 3999 def update_application_resource_lifecycle(params = {}, = {}) req = build_request(:update_application_resource_lifecycle, params) req.send_request() end |
#update_application_version(params = {}) ⇒ Types::ApplicationVersionDescriptionMessage
Updates the specified application version to have the specified properties.
<note markdown=“1”> If a property (for example, ‘description`) is not provided, the value remains unchanged. To clear properties, specify an empty string.
</note>
4085 4086 4087 4088 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 4085 def update_application_version(params = {}, = {}) req = build_request(:update_application_version, params) req.send_request() end |
#update_configuration_template(params = {}) ⇒ Types::ConfigurationSettingsDescription
Updates the specified configuration template to have the specified properties or configuration option values.
<note markdown=“1”> If a property (for example, ‘ApplicationName`) is not provided, its value remains unchanged. To clear such properties, specify an empty string.
</note>
Related Topics
-
DescribeConfigurationOptions
^
4215 4216 4217 4218 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 4215 def update_configuration_template(params = {}, = {}) req = build_request(:update_configuration_template, params) req.send_request() end |
#update_environment(params = {}) ⇒ Types::EnvironmentDescription
Updates the environment description, deploys a new application version, updates the configuration settings to an entirely new configuration template, or updates select configuration option values in the running environment.
Attempting to update both the release and configuration is not allowed and AWS Elastic Beanstalk returns an ‘InvalidParameterCombination` error.
When updating the configuration settings to a new template or individual settings, a draft configuration is created and DescribeConfigurationSettings for this environment returns two setting descriptions with different ‘DeploymentStatus` values.
4478 4479 4480 4481 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 4478 def update_environment(params = {}, = {}) req = build_request(:update_environment, params) req.send_request() end |
#update_tags_for_resource(params = {}) ⇒ Struct
Update the list of tags applied to an AWS Elastic Beanstalk resource. Two lists can be passed: ‘TagsToAdd` for tags to add or update, and `TagsToRemove`.
Elastic Beanstalk supports tagging of all of its resources. For details about resource tagging, see [Tagging Application Resources].
If you create a custom IAM user policy to control permission to this operation, specify one of the following two virtual actions (or both) instead of the API operation name:
elasticbeanstalk:AddTags
: Controls permission to call ‘UpdateTagsForResource` and pass a list
of tags to add in the `TagsToAdd` parameter.
elasticbeanstalk:RemoveTags
: Controls permission to call ‘UpdateTagsForResource` and pass a list
of tag keys to remove in the `TagsToRemove` parameter.
For details about creating a custom user policy, see [Creating a Custom User Policy].
[1]: docs.aws.amazon.com/elasticbeanstalk/latest/dg/applications-tagging-resources.html [2]: docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.managed-policies.html#AWSHowTo.iam.policies
4549 4550 4551 4552 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 4549 def (params = {}, = {}) req = build_request(:update_tags_for_resource, params) req.send_request() end |
#validate_configuration_settings(params = {}) ⇒ Types::ConfigurationSettingsValidationMessages
Takes a set of configuration settings and either a configuration template or environment, and determines whether those values are valid.
This action returns a list of messages indicating any errors or warnings associated with the selection of option values.
4635 4636 4637 4638 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 4635 def validate_configuration_settings(params = {}, = {}) req = build_request(:validate_configuration_settings, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.
| waiter_name | params | :delay | :max_attempts | | ———————- | —————————— | ——– | ————- | | environment_exists | #describe_environments | 20 | 20 | | environment_terminated | #describe_environments | 20 | 20 | | environment_updated | #describe_environments | 20 | 20 |
4752 4753 4754 4755 4756 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 4752 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4760 4761 4762 |
# File 'lib/aws-sdk-elasticbeanstalk/client.rb', line 4760 def waiter_names waiters.keys end |