Class: Aws::ElasticBeanstalk::Types::ApplicationVersionDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::ApplicationVersionDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Describes the properties of an application version.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of the application to which the application version belongs.
-
#application_version_arn ⇒ String
The Amazon Resource Name (ARN) of the application version.
-
#build_arn ⇒ String
Reference to the artifact from the CodeBuild build.
-
#date_created ⇒ Time
The creation date of the application version.
-
#date_updated ⇒ Time
The last modified date of the application version.
-
#description ⇒ String
The description of the application version.
-
#image_build_configuration ⇒ Types::ImageBuildConfiguration
The settings that Elastic Beanstalk uses to build a container image from the source bundle of the application version.
-
#image_source ⇒ Types::ImageSource
The location of the container image for the application version.
-
#process ⇒ Boolean
Indicates whether Elastic Beanstalk pre-processed and validated the environment manifest (
env.yaml) and configuration files (*.configfiles in the.ebextensionsfolder) in the source bundle of the application version. -
#source_build_information ⇒ Types::SourceBuildInformation
If the version's source code was retrieved from CodeCommit, the location of the source code for the application version.
-
#source_bundle ⇒ Types::S3Location
The storage location of the application version's source bundle in Amazon S3.
-
#status ⇒ String
The processing status of the application version.
-
#version_label ⇒ String
A unique identifier for the application version.
Instance Attribute Details
#application_name ⇒ String
The name of the application to which the application version belongs.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 286 class ApplicationVersionDescription < Struct.new( :application_version_arn, :application_name, :description, :version_label, :source_build_information, :build_arn, :source_bundle, :image_source, :image_build_configuration, :process, :date_created, :date_updated, :status) SENSITIVE = [] include Aws::Structure end |
#application_version_arn ⇒ String
The Amazon Resource Name (ARN) of the application version.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 286 class ApplicationVersionDescription < Struct.new( :application_version_arn, :application_name, :description, :version_label, :source_build_information, :build_arn, :source_bundle, :image_source, :image_build_configuration, :process, :date_created, :date_updated, :status) SENSITIVE = [] include Aws::Structure end |
#build_arn ⇒ String
Reference to the artifact from the CodeBuild build.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 286 class ApplicationVersionDescription < Struct.new( :application_version_arn, :application_name, :description, :version_label, :source_build_information, :build_arn, :source_bundle, :image_source, :image_build_configuration, :process, :date_created, :date_updated, :status) SENSITIVE = [] include Aws::Structure end |
#date_created ⇒ Time
The creation date of the application version.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 286 class ApplicationVersionDescription < Struct.new( :application_version_arn, :application_name, :description, :version_label, :source_build_information, :build_arn, :source_bundle, :image_source, :image_build_configuration, :process, :date_created, :date_updated, :status) SENSITIVE = [] include Aws::Structure end |
#date_updated ⇒ Time
The last modified date of the application version.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 286 class ApplicationVersionDescription < Struct.new( :application_version_arn, :application_name, :description, :version_label, :source_build_information, :build_arn, :source_bundle, :image_source, :image_build_configuration, :process, :date_created, :date_updated, :status) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the application version.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 286 class ApplicationVersionDescription < Struct.new( :application_version_arn, :application_name, :description, :version_label, :source_build_information, :build_arn, :source_bundle, :image_source, :image_build_configuration, :process, :date_created, :date_updated, :status) SENSITIVE = [] include Aws::Structure end |
#image_build_configuration ⇒ Types::ImageBuildConfiguration
The settings that Elastic Beanstalk uses to build a container image from the source bundle of the application version. Not present for an application version created from an image you provide.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 286 class ApplicationVersionDescription < Struct.new( :application_version_arn, :application_name, :description, :version_label, :source_build_information, :build_arn, :source_bundle, :image_source, :image_build_configuration, :process, :date_created, :date_updated, :status) SENSITIVE = [] include Aws::Structure end |
#image_source ⇒ Types::ImageSource
The location of the container image for the application version.
For an application version created from an image you provide, this is that image. For one that Elastic Beanstalk builds from your source bundle, Elastic Beanstalk fills this in with the image it pushed after the build succeeds.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 286 class ApplicationVersionDescription < Struct.new( :application_version_arn, :application_name, :description, :version_label, :source_build_information, :build_arn, :source_bundle, :image_source, :image_build_configuration, :process, :date_created, :date_updated, :status) SENSITIVE = [] include Aws::Structure end |
#process ⇒ Boolean
Indicates whether Elastic Beanstalk pre-processed and validated the
environment manifest (env.yaml) and configuration files
(*.config files in the .ebextensions folder) in the source
bundle of the application version.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 286 class ApplicationVersionDescription < Struct.new( :application_version_arn, :application_name, :description, :version_label, :source_build_information, :build_arn, :source_bundle, :image_source, :image_build_configuration, :process, :date_created, :date_updated, :status) SENSITIVE = [] include Aws::Structure end |
#source_build_information ⇒ Types::SourceBuildInformation
If the version's source code was retrieved from CodeCommit, the location of the source code for the application version.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 286 class ApplicationVersionDescription < Struct.new( :application_version_arn, :application_name, :description, :version_label, :source_build_information, :build_arn, :source_bundle, :image_source, :image_build_configuration, :process, :date_created, :date_updated, :status) SENSITIVE = [] include Aws::Structure end |
#source_bundle ⇒ Types::S3Location
The storage location of the application version's source bundle in Amazon S3.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 286 class ApplicationVersionDescription < Struct.new( :application_version_arn, :application_name, :description, :version_label, :source_build_information, :build_arn, :source_bundle, :image_source, :image_build_configuration, :process, :date_created, :date_updated, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The processing status of the application version. Reflects the state
of the application version during its creation. Many of the values
are only applicable if you specified True for the Process
parameter of the CreateApplicationVersion action. The following
list describes the possible values.
-
Unprocessed– Application version wasn't pre-processed or validated. Elastic Beanstalk will validate configuration files during deployment of the application version to an environment. -
Processing– Elastic Beanstalk is currently processing the application version. -
Building– Application version is currently undergoing an CodeBuild build. -
Processed– Elastic Beanstalk was successfully pre-processed and validated. -
Failed– Either the CodeBuild build failed or configuration files didn't pass validation. This application version isn't usable.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 286 class ApplicationVersionDescription < Struct.new( :application_version_arn, :application_name, :description, :version_label, :source_build_information, :build_arn, :source_bundle, :image_source, :image_build_configuration, :process, :date_created, :date_updated, :status) SENSITIVE = [] include Aws::Structure end |
#version_label ⇒ String
A unique identifier for the application version.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 286 class ApplicationVersionDescription < Struct.new( :application_version_arn, :application_name, :description, :version_label, :source_build_information, :build_arn, :source_bundle, :image_source, :image_build_configuration, :process, :date_created, :date_updated, :status) SENSITIVE = [] include Aws::Structure end |