Class: Aws::ElasticBeanstalk::Types::DeleteApplicationVersionMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::DeleteApplicationVersionMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Request to delete an application version.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
The name of the application to which the version belongs.
-
#delete_source_bundle ⇒ Boolean
Set to
trueto delete the source bundle from your storage bucket. -
#version_label ⇒ String
The label of the version to delete.
Instance Attribute Details
#application_name ⇒ String
The name of the application to which the version belongs.
1495 1496 1497 1498 1499 1500 1501 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1495 class DeleteApplicationVersionMessage < Struct.new( :application_name, :version_label, :delete_source_bundle) SENSITIVE = [] include Aws::Structure end |
#delete_source_bundle ⇒ Boolean
Set to true to delete the source bundle from your storage bucket.
Otherwise, the application version is deleted only from Elastic
Beanstalk and the source bundle remains in Amazon S3.
1495 1496 1497 1498 1499 1500 1501 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1495 class DeleteApplicationVersionMessage < Struct.new( :application_name, :version_label, :delete_source_bundle) SENSITIVE = [] include Aws::Structure end |
#version_label ⇒ String
The label of the version to delete.
1495 1496 1497 1498 1499 1500 1501 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 1495 class DeleteApplicationVersionMessage < Struct.new( :application_name, :version_label, :delete_source_bundle) SENSITIVE = [] include Aws::Structure end |