Class: Aws::ElasticBeanstalk::Types::DescribeEventsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::DescribeEventsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Request to retrieve a list of events for an environment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_name ⇒ String
If specified, Elastic Beanstalk restricts the returned descriptions to include only those associated with this application.
-
#end_time ⇒ Time
If specified, Elastic Beanstalk restricts the returned descriptions to those that occur up to, but not including, the
EndTime. -
#environment_id ⇒ String
If specified, Elastic Beanstalk restricts the returned descriptions to those associated with this environment.
-
#environment_name ⇒ String
If specified, Elastic Beanstalk restricts the returned descriptions to those associated with this environment.
-
#max_records ⇒ Integer
Specifies the maximum number of events that can be returned, beginning with the most recent event.
-
#next_token ⇒ String
Pagination token.
-
#platform_arn ⇒ String
The ARN of a custom platform version.
-
#request_id ⇒ String
If specified, Elastic Beanstalk restricts the described events to include only those associated with this request ID.
-
#severity ⇒ String
If specified, limits the events returned from this call to include only those with the specified severity or higher.
-
#start_time ⇒ Time
If specified, Elastic Beanstalk restricts the returned descriptions to those that occur on or after this time.
-
#template_name ⇒ String
If specified, Elastic Beanstalk restricts the returned descriptions to those that are associated with this environment configuration.
-
#version_label ⇒ String
If specified, Elastic Beanstalk restricts the returned descriptions to those associated with this application version.
Instance Attribute Details
#application_name ⇒ String
If specified, Elastic Beanstalk restricts the returned descriptions to include only those associated with this application.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2094 class DescribeEventsMessage < Struct.new( :application_name, :version_label, :template_name, :environment_id, :environment_name, :platform_arn, :request_id, :severity, :start_time, :end_time, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
If specified, Elastic Beanstalk restricts the returned descriptions
to those that occur up to, but not including, the EndTime.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2094 class DescribeEventsMessage < Struct.new( :application_name, :version_label, :template_name, :environment_id, :environment_name, :platform_arn, :request_id, :severity, :start_time, :end_time, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
If specified, Elastic Beanstalk restricts the returned descriptions to those associated with this environment.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2094 class DescribeEventsMessage < Struct.new( :application_name, :version_label, :template_name, :environment_id, :environment_name, :platform_arn, :request_id, :severity, :start_time, :end_time, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#environment_name ⇒ String
If specified, Elastic Beanstalk restricts the returned descriptions to those associated with this environment.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2094 class DescribeEventsMessage < Struct.new( :application_name, :version_label, :template_name, :environment_id, :environment_name, :platform_arn, :request_id, :severity, :start_time, :end_time, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
Specifies the maximum number of events that can be returned, beginning with the most recent event.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2094 class DescribeEventsMessage < Struct.new( :application_name, :version_label, :template_name, :environment_id, :environment_name, :platform_arn, :request_id, :severity, :start_time, :end_time, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Pagination token. If specified, the events return the next batch of results.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2094 class DescribeEventsMessage < Struct.new( :application_name, :version_label, :template_name, :environment_id, :environment_name, :platform_arn, :request_id, :severity, :start_time, :end_time, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#platform_arn ⇒ String
The ARN of a custom platform version. If specified, Elastic Beanstalk restricts the returned descriptions to those associated with this custom platform version.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2094 class DescribeEventsMessage < Struct.new( :application_name, :version_label, :template_name, :environment_id, :environment_name, :platform_arn, :request_id, :severity, :start_time, :end_time, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
If specified, Elastic Beanstalk restricts the described events to include only those associated with this request ID.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2094 class DescribeEventsMessage < Struct.new( :application_name, :version_label, :template_name, :environment_id, :environment_name, :platform_arn, :request_id, :severity, :start_time, :end_time, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ String
If specified, limits the events returned from this call to include only those with the specified severity or higher.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2094 class DescribeEventsMessage < Struct.new( :application_name, :version_label, :template_name, :environment_id, :environment_name, :platform_arn, :request_id, :severity, :start_time, :end_time, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
If specified, Elastic Beanstalk restricts the returned descriptions to those that occur on or after this time.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2094 class DescribeEventsMessage < Struct.new( :application_name, :version_label, :template_name, :environment_id, :environment_name, :platform_arn, :request_id, :severity, :start_time, :end_time, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#template_name ⇒ String
If specified, Elastic Beanstalk restricts the returned descriptions to those that are associated with this environment configuration.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2094 class DescribeEventsMessage < Struct.new( :application_name, :version_label, :template_name, :environment_id, :environment_name, :platform_arn, :request_id, :severity, :start_time, :end_time, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |
#version_label ⇒ String
If specified, Elastic Beanstalk restricts the returned descriptions to those associated with this application version.
2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 2094 class DescribeEventsMessage < Struct.new( :application_name, :version_label, :template_name, :environment_id, :environment_name, :platform_arn, :request_id, :severity, :start_time, :end_time, :max_records, :next_token) SENSITIVE = [] include Aws::Structure end |