Class: Aws::ElasticBeanstalk::Types::PlatformDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::PlatformDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
Detailed information about a platform version.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_ami_list ⇒ Array<Types::CustomAmi>
The custom AMIs supported by the platform version.
-
#date_created ⇒ Time
The date when the platform version was created.
-
#date_updated ⇒ Time
The date when the platform version was last updated.
-
#description ⇒ String
The description of the platform version.
-
#frameworks ⇒ Array<Types::PlatformFramework>
The frameworks supported by the platform version.
-
#maintainer ⇒ String
Information about the maintainer of the platform version.
-
#operating_system_name ⇒ String
The operating system used by the platform version.
-
#operating_system_version ⇒ String
The version of the operating system used by the platform version.
-
#platform_arn ⇒ String
The ARN of the platform version.
-
#platform_branch_lifecycle_state ⇒ String
The state of the platform version's branch in its lifecycle.
-
#platform_branch_name ⇒ String
The platform branch to which the platform version belongs.
-
#platform_category ⇒ String
The category of the platform version.
-
#platform_lifecycle_state ⇒ String
The state of the platform version in its lifecycle.
-
#platform_name ⇒ String
The name of the platform version.
-
#platform_owner ⇒ String
The Amazon Web Services account ID of the person who created the platform version.
-
#platform_status ⇒ String
The status of the platform version.
-
#platform_version ⇒ String
The version of the platform version.
-
#programming_languages ⇒ Array<Types::PlatformProgrammingLanguage>
The programming languages supported by the platform version.
-
#solution_stack_name ⇒ String
The name of the solution stack used by the platform version.
-
#supported_addon_list ⇒ Array<String>
The additions supported by the platform version.
-
#supported_tier_list ⇒ Array<String>
The tiers supported by the platform version.
Instance Attribute Details
#custom_ami_list ⇒ Array<Types::CustomAmi>
The custom AMIs supported by the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#date_created ⇒ Time
The date when the platform version was created.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#date_updated ⇒ Time
The date when the platform version was last updated.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#frameworks ⇒ Array<Types::PlatformFramework>
The frameworks supported by the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#maintainer ⇒ String
Information about the maintainer of the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#operating_system_name ⇒ String
The operating system used by the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#operating_system_version ⇒ String
The version of the operating system used by the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#platform_arn ⇒ String
The ARN of the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#platform_branch_lifecycle_state ⇒ String
The state of the platform version's branch in its lifecycle.
Possible values: Beta | Supported | Deprecated | Retired
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#platform_branch_name ⇒ String
The platform branch to which the platform version belongs.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#platform_category ⇒ String
The category of the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#platform_lifecycle_state ⇒ String
The state of the platform version in its lifecycle.
Possible values: Recommended | null
If a null value is returned, the platform version isn't the recommended one for its branch. Each platform branch has a single recommended platform version, typically the most recent one.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#platform_name ⇒ String
The name of the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#platform_owner ⇒ String
The Amazon Web Services account ID of the person who created the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#platform_status ⇒ String
The status of the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#platform_version ⇒ String
The version of the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#programming_languages ⇒ Array<Types::PlatformProgrammingLanguage>
The programming languages supported by the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#solution_stack_name ⇒ String
The name of the solution stack used by the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#supported_addon_list ⇒ Array<String>
The additions supported by the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |
#supported_tier_list ⇒ Array<String>
The tiers supported by the platform version.
3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3556 class PlatformDescription < Struct.new( :platform_arn, :platform_owner, :platform_name, :platform_version, :solution_stack_name, :platform_status, :date_created, :date_updated, :platform_category, :description, :maintainer, :operating_system_name, :operating_system_version, :programming_languages, :frameworks, :custom_ami_list, :supported_tier_list, :supported_addon_list, :platform_lifecycle_state, :platform_branch_name, :platform_branch_lifecycle_state) SENSITIVE = [] include Aws::Structure end |