Class: Aws::ElasticBeanstalk::Types::ResourceQuota
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticBeanstalk::Types::ResourceQuota
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticbeanstalk/types.rb
Overview
The Elastic Beanstalk quota information for a single resource type in an Amazon Web Services account. It reflects the resource's limits for this account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#maximum ⇒ Integer
The maximum number of instances of this Elastic Beanstalk resource type that an Amazon Web Services account can use.
Instance Attribute Details
#maximum ⇒ Integer
The maximum number of instances of this Elastic Beanstalk resource type that an Amazon Web Services account can use.
3856 3857 3858 3859 3860 |
# File 'lib/aws-sdk-elasticbeanstalk/types.rb', line 3856 class ResourceQuota < Struct.new( :maximum) SENSITIVE = [] include Aws::Structure end |